"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Protocol Buffers - Google's data interchange format
Copyright 2008 Google Inc.  All rights reserved.
https://developers.google.com/protocol-buffers/

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Wrappers for primitive (non-message) types. These types were needed
for legacy reasons and are not recommended for use in new APIs.

Historically these wrappers were useful to have presence on proto3 primitive
fields, but proto3 syntax has been updated to support the `optional` keyword.
Using that keyword is now the strongly preferred way to add presence to
proto3 primitive fields.

A secondary usecase was to embed primitives in the `google.protobuf.Any`
type: it is now recommended that you embed your value in your own wrapper
message which can be specifically documented.

These wrappers have no meaningful use within repeated fields as they lack
the ability to detect presence on individual elements.
These wrappers have no meaningful use within a map or a oneof since
individual entries of a map or fields of a oneof can already detect presence.
"""

import builtins
import typing

import google.protobuf.descriptor
import google.protobuf.message

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DoubleValue(google.protobuf.message.Message):
    """Wrapper message for `double`.

    The JSON representation for `DoubleValue` is JSON number.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.float
    """The double value."""
    def __init__(self, *, value: builtins.float | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___DoubleValue = DoubleValue

@typing.final
class FloatValue(google.protobuf.message.Message):
    """Wrapper message for `float`.

    The JSON representation for `FloatValue` is JSON number.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.float
    """The float value."""
    def __init__(self, *, value: builtins.float | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___FloatValue = FloatValue

@typing.final
class Int64Value(google.protobuf.message.Message):
    """Wrapper message for `int64`.

    The JSON representation for `Int64Value` is JSON string.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    """The int64 value."""
    def __init__(self, *, value: builtins.int | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Int64Value = Int64Value

@typing.final
class UInt64Value(google.protobuf.message.Message):
    """Wrapper message for `uint64`.

    The JSON representation for `UInt64Value` is JSON string.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    """The uint64 value."""
    def __init__(self, *, value: builtins.int | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___UInt64Value = UInt64Value

@typing.final
class Int32Value(google.protobuf.message.Message):
    """Wrapper message for `int32`.

    The JSON representation for `Int32Value` is JSON number.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    """The int32 value."""
    def __init__(self, *, value: builtins.int | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___Int32Value = Int32Value

@typing.final
class UInt32Value(google.protobuf.message.Message):
    """Wrapper message for `uint32`.

    The JSON representation for `UInt32Value` is JSON number.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    """The uint32 value."""
    def __init__(self, *, value: builtins.int | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___UInt32Value = UInt32Value

@typing.final
class BoolValue(google.protobuf.message.Message):
    """Wrapper message for `bool`.

    The JSON representation for `BoolValue` is JSON `true` and `false`.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    """The bool value."""
    def __init__(self, *, value: builtins.bool | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___BoolValue = BoolValue

@typing.final
class StringValue(google.protobuf.message.Message):
    """Wrapper message for `string`.

    The JSON representation for `StringValue` is JSON string.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    """The string value."""
    def __init__(self, *, value: builtins.str | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___StringValue = StringValue

@typing.final
class BytesValue(google.protobuf.message.Message):
    """Wrapper message for `bytes`.

    The JSON representation for `BytesValue` is JSON string.

    Not recommended for use in new APIs, but still useful for legacy APIs and
    has no plan to be removed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bytes
    """The bytes value."""
    def __init__(self, *, value: builtins.bytes | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___BytesValue = BytesValue



import argparse
import configparser
from collections.abc import Sequence
from logging import Logger

from .manager import OptionManager

LOG: Logger

def aggregate_options(
    manager: OptionManager, cfg: configparser.RawConfigParser, cfg_dir: str, argv: Sequence[str] | None
) -> argparse.Namespace: ...



import logging
from typing import Literal

from docker.types.swarm import SwarmSpec

log: logging.Logger

class SwarmApiMixin:
    def create_swarm_spec(self, *args, **kwargs) -> SwarmSpec: ...
    def get_unlock_key(self): ...
    def init_swarm(
        self,
        advertise_addr=None,
        listen_addr: str = "0.0.0.0:2377",
        force_new_cluster: bool = False,
        swarm_spec=None,
        default_addr_pool=None,
        subnet_size=None,
        data_path_addr=None,
        data_path_port=None,
    ): ...
    def inspect_swarm(self): ...
    def inspect_node(self, node_id): ...
    def join_swarm(
        self, remote_addrs, join_token, listen_addr: str = "0.0.0.0:2377", advertise_addr=None, data_path_addr=None
    ) -> Literal[True]: ...
    def leave_swarm(self, force: bool = False) -> Literal[True]: ...
    def nodes(self, filters=None): ...
    def remove_node(self, node_id, force: bool = False) -> Literal[True]: ...
    def unlock_swarm(self, key) -> Literal[True]: ...
    def update_node(self, node_id, version, node_spec=None) -> Literal[True]: ...
    def update_swarm(
        self,
        version,
        swarm_spec=None,
        rotate_worker_token: bool = False,
        rotate_manager_token: bool = False,
        rotate_manager_unlock_key: bool = False,
    ) -> Literal[True]: ...



from _typeshed import Incomplete

from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
from braintree.android_pay_card import AndroidPayCard
from braintree.apple_pay_card import ApplePayCard
from braintree.credit_card import CreditCard
from braintree.error_result import ErrorResult
from braintree.europe_bank_account import EuropeBankAccount
from braintree.masterpass_card import MasterpassCard
from braintree.paypal_account import PayPalAccount
from braintree.samsung_pay_card import SamsungPayCard
from braintree.sepa_direct_debit_account import SepaDirectDebitAccount
from braintree.successful_result import SuccessfulResult
from braintree.unknown_payment_method import UnknownPaymentMethod
from braintree.us_bank_account import UsBankAccount
from braintree.venmo_account import VenmoAccount
from braintree.visa_checkout_card import VisaCheckoutCard

class PaymentMethodGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def create(self, params: dict[str, Incomplete] | None = None) -> SuccessfulResult | ErrorResult: ...
    def find(
        self, payment_method_token: str
    ) -> (
        AndroidPayCard
        | ApplePayCard
        | EuropeBankAccount
        | CreditCard
        | PayPalAccount
        | UsBankAccount
        | VenmoAccount
        | VisaCheckoutCard
        | AmexExpressCheckoutCard
        | SepaDirectDebitAccount
        | MasterpassCard
        | SamsungPayCard
        | UnknownPaymentMethod
    ): ...
    def update(self, payment_method_token: str, params) -> SuccessfulResult | ErrorResult: ...
    def delete(self, payment_method_token: str, options=None) -> SuccessfulResult: ...
    options: dict[str, Incomplete]
    def grant(self, payment_method_token: str, options=None) -> SuccessfulResult | ErrorResult: ...
    def revoke(self, payment_method_token: str) -> SuccessfulResult | ErrorResult: ...



from _typeshed import Unused
from typing import Final

from Xlib.display import Display
from Xlib.protocol import rq
from Xlib.xobject import resource

extname: Final = "NV-CONTROL"

def query_target_count(self: Display | resource.Resource, target: Target) -> int: ...
def query_int_attribute(self: Display | resource.Resource, target: Target, display_mask: int, attr: int) -> int | None: ...
def set_int_attribute(self: Display | resource.Resource, target: Target, display_mask: int, attr: int, value: int) -> bool: ...
def query_string_attribute(self: Display | resource.Resource, target: Target, display_mask: int, attr: int) -> str | None: ...
def query_valid_attr_values(
    self: Display | resource.Resource, target: Target, display_mask: int, attr: int
) -> tuple[int, int] | None: ...
def query_binary_data(self: Display | resource.Resource, target: Target, display_mask: int, attr: int) -> bytes | None: ...
def get_coolers_used_by_gpu(self: Display | resource.Resource, target: Target) -> list[int] | None: ...
def get_gpu_count(self: Display | resource.Resource) -> int: ...
def get_name(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_driver_version(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_vbios_version(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_gpu_uuid(self: Display | resource.Resource, target: Target) -> str | None: ...
def get_utilization_rates(self: Display | resource.Resource, target: Target) -> dict[str, str | int]: ...
def get_performance_modes(self: Display | resource.Resource, target: Target) -> list[dict[str, str | int]]: ...
def get_clock_info(self: Display | resource.Resource, target: Target) -> dict[str, str | int]: ...
def get_vram(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_irq(self: Display | resource.Resource, target: Target) -> int | None: ...
def supports_framelock(self: Display | resource.Resource, target: Target) -> int | None: ...
def gvo_supported(self: Display | resource.Resource, screen: Target) -> int | None: ...
def get_core_temp(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_core_threshold(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_default_core_threshold(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_max_core_threshold(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_ambient_temp(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_cuda_cores(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_memory_bus_width(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_total_dedicated_gpu_memory(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_used_dedicated_gpu_memory(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_curr_pcie_link_width(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_max_pcie_link_width(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_curr_pcie_link_generation(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_encoder_utilization(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_decoder_utilization(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_current_performance_level(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_gpu_nvclock_offset(self: Display | resource.Resource, target: Target, perf_level: int) -> int | None: ...
def set_gpu_nvclock_offset(self: Display | resource.Resource, target: Target, perf_level: int, offset: int) -> bool: ...
def set_gpu_nvclock_offset_all_levels(self: Display | resource.Resource, target: Target, offset: int) -> bool: ...
def get_gpu_nvclock_offset_range(
    self: Display | resource.Resource, target: Target, perf_level: int
) -> tuple[int, int] | None: ...
def get_mem_transfer_rate_offset(self: Display | resource.Resource, target: Target, perf_level: int) -> int | None: ...
def set_mem_transfer_rate_offset(self: Display | resource.Resource, target: Target, perf_level: int, offset: int) -> bool: ...
def set_mem_transfer_rate_offset_all_levels(self: Display | resource.Resource, target: Target, offset: int) -> bool: ...
def get_mem_transfer_rate_offset_range(
    self: Display | resource.Resource, target: Target, perf_level: int
) -> tuple[int, int] | None: ...
def get_cooler_manual_control_enabled(self: Display | resource.Resource, target: Target) -> int | None: ...
def set_cooler_manual_control_enabled(self: Display | resource.Resource, target: Target, enabled: bool) -> bool: ...
def get_fan_duty(self: Display | resource.Resource, target: Target) -> int | None: ...
def set_fan_duty(self: Display | resource.Resource, cooler: Target, speed: int) -> bool: ...
def get_fan_rpm(self: Display | resource.Resource, target: Target) -> int | None: ...
def get_max_displays(self: Display | resource.Resource, target: Target) -> int | None: ...
def init(disp: Display, info: Unused) -> None: ...

NV_CTRL_FLATPANEL_SCALING: Final = 2
NV_CTRL_FLATPANEL_SCALING_DEFAULT: Final = 0
NV_CTRL_FLATPANEL_SCALING_NATIVE: Final = 1
NV_CTRL_FLATPANEL_SCALING_SCALED: Final = 2
NV_CTRL_FLATPANEL_SCALING_CENTERED: Final = 3
NV_CTRL_FLATPANEL_SCALING_ASPECT_SCALED: Final = 4
NV_CTRL_FLATPANEL_DITHERING: Final = 3
NV_CTRL_FLATPANEL_DITHERING_DEFAULT: Final = 0
NV_CTRL_FLATPANEL_DITHERING_ENABLED: Final = 1
NV_CTRL_FLATPANEL_DITHERING_DISABLED: Final = 2
NV_CTRL_DITHERING: Final = 3
NV_CTRL_DITHERING_AUTO: Final = 0
NV_CTRL_DITHERING_ENABLED: Final = 1
NV_CTRL_DITHERING_DISABLED: Final = 2
NV_CTRL_DIGITAL_VIBRANCE: Final = 4
NV_CTRL_BUS_TYPE: Final = 5
NV_CTRL_BUS_TYPE_AGP: Final = 0
NV_CTRL_BUS_TYPE_PCI: Final = 1
NV_CTRL_BUS_TYPE_PCI_EXPRESS: Final = 2
NV_CTRL_BUS_TYPE_INTEGRATED: Final = 3
NV_CTRL_TOTAL_GPU_MEMORY: Final = 6
NV_CTRL_VIDEO_RAM: Final = NV_CTRL_TOTAL_GPU_MEMORY
NV_CTRL_IRQ: Final = 7
NV_CTRL_OPERATING_SYSTEM: Final = 8
NV_CTRL_OPERATING_SYSTEM_LINUX: Final = 0
NV_CTRL_OPERATING_SYSTEM_FREEBSD: Final = 1
NV_CTRL_OPERATING_SYSTEM_SUNOS: Final = 2
NV_CTRL_SYNC_TO_VBLANK: Final = 9
NV_CTRL_SYNC_TO_VBLANK_OFF: Final = 0
NV_CTRL_SYNC_TO_VBLANK_ON: Final = 1
NV_CTRL_LOG_ANISO: Final = 10
NV_CTRL_FSAA_MODE: Final = 11
NV_CTRL_FSAA_MODE_NONE: Final = 0
NV_CTRL_FSAA_MODE_2x: Final = 1
NV_CTRL_FSAA_MODE_2x_5t: Final = 2
NV_CTRL_FSAA_MODE_15x15: Final = 3
NV_CTRL_FSAA_MODE_2x2: Final = 4
NV_CTRL_FSAA_MODE_4x: Final = 5
NV_CTRL_FSAA_MODE_4x_9t: Final = 6
NV_CTRL_FSAA_MODE_8x: Final = 7
NV_CTRL_FSAA_MODE_16x: Final = 8
NV_CTRL_FSAA_MODE_8xS: Final = 9
NV_CTRL_FSAA_MODE_8xQ: Final = 10
NV_CTRL_FSAA_MODE_16xS: Final = 11
NV_CTRL_FSAA_MODE_16xQ: Final = 12
NV_CTRL_FSAA_MODE_32xS: Final = 13
NV_CTRL_FSAA_MODE_32x: Final = 14
NV_CTRL_FSAA_MODE_64xS: Final = 15
NV_CTRL_FSAA_MODE_MAX: Final = NV_CTRL_FSAA_MODE_64xS
NV_CTRL_UBB: Final = 13
NV_CTRL_UBB_OFF: Final = 0
NV_CTRL_UBB_ON: Final = 1
NV_CTRL_OVERLAY: Final = 14
NV_CTRL_OVERLAY_OFF: Final = 0
NV_CTRL_OVERLAY_ON: Final = 1
NV_CTRL_STEREO: Final = 16
NV_CTRL_STEREO_OFF: Final = 0
NV_CTRL_STEREO_DDC: Final = 1
NV_CTRL_STEREO_BLUELINE: Final = 2
NV_CTRL_STEREO_DIN: Final = 3
NV_CTRL_STEREO_PASSIVE_EYE_PER_DPY: Final = 4
NV_CTRL_STEREO_VERTICAL_INTERLACED: Final = 5
NV_CTRL_STEREO_COLOR_INTERLACED: Final = 6
NV_CTRL_STEREO_HORIZONTAL_INTERLACED: Final = 7
NV_CTRL_STEREO_CHECKERBOARD_PATTERN: Final = 8
NV_CTRL_STEREO_INVERSE_CHECKERBOARD_PATTERN: Final = 9
NV_CTRL_STEREO_3D_VISION: Final = 10
NV_CTRL_STEREO_3D_VISION_PRO: Final = 11
NV_CTRL_STEREO_HDMI_3D: Final = 12
NV_CTRL_STEREO_TRIDELITY_SL: Final = 13
NV_CTRL_STEREO_INBAND_STEREO_SIGNALING: Final = 14
NV_CTRL_STEREO_MAX: Final = NV_CTRL_STEREO_INBAND_STEREO_SIGNALING
NV_CTRL_EMULATE: Final = 17
NV_CTRL_EMULATE_NONE: Final = 0
NV_CTRL_TWINVIEW: Final = 18
NV_CTRL_TWINVIEW_NOT_ENABLED: Final = 0
NV_CTRL_TWINVIEW_ENABLED: Final = 1
NV_CTRL_CONNECTED_DISPLAYS: Final = 19
NV_CTRL_ENABLED_DISPLAYS: Final = 20
NV_CTRL_FRAMELOCK: Final = 21
NV_CTRL_FRAMELOCK_NOT_SUPPORTED: Final = 0
NV_CTRL_FRAMELOCK_SUPPORTED: Final = 1
NV_CTRL_FRAMELOCK_MASTER: Final = 22
NV_CTRL_FRAMELOCK_MASTER_FALSE: Final = 0
NV_CTRL_FRAMELOCK_MASTER_TRUE: Final = 1
NV_CTRL_FRAMELOCK_POLARITY: Final = 23
NV_CTRL_FRAMELOCK_POLARITY_RISING_EDGE: Final = 0x1
NV_CTRL_FRAMELOCK_POLARITY_FALLING_EDGE: Final = 0x2
NV_CTRL_FRAMELOCK_POLARITY_BOTH_EDGES: Final = 0x3
NV_CTRL_FRAMELOCK_SYNC_DELAY: Final = 24
NV_CTRL_FRAMELOCK_SYNC_DELAY_MAX: Final = 2047
NV_CTRL_FRAMELOCK_SYNC_DELAY_FACTOR: Final[float]
NV_CTRL_FRAMELOCK_SYNC_INTERVAL: Final = 25
NV_CTRL_FRAMELOCK_PORT0_STATUS: Final = 26
NV_CTRL_FRAMELOCK_PORT0_STATUS_INPUT: Final = 0
NV_CTRL_FRAMELOCK_PORT0_STATUS_OUTPUT: Final = 1
NV_CTRL_FRAMELOCK_PORT1_STATUS: Final = 27
NV_CTRL_FRAMELOCK_PORT1_STATUS_INPUT: Final = 0
NV_CTRL_FRAMELOCK_PORT1_STATUS_OUTPUT: Final = 1
NV_CTRL_FRAMELOCK_HOUSE_STATUS: Final = 28
NV_CTRL_FRAMELOCK_HOUSE_STATUS_NOT_DETECTED: Final = 0
NV_CTRL_FRAMELOCK_HOUSE_STATUS_DETECTED: Final = 1
NV_CTRL_FRAMELOCK_SYNC: Final = 29
NV_CTRL_FRAMELOCK_SYNC_DISABLE: Final = 0
NV_CTRL_FRAMELOCK_SYNC_ENABLE: Final = 1
NV_CTRL_FRAMELOCK_SYNC_READY: Final = 30
NV_CTRL_FRAMELOCK_SYNC_READY_FALSE: Final = 0
NV_CTRL_FRAMELOCK_SYNC_READY_TRUE: Final = 1
NV_CTRL_FRAMELOCK_STEREO_SYNC: Final = 31
NV_CTRL_FRAMELOCK_STEREO_SYNC_FALSE: Final = 0
NV_CTRL_FRAMELOCK_STEREO_SYNC_TRUE: Final = 1
NV_CTRL_FRAMELOCK_TEST_SIGNAL: Final = 32
NV_CTRL_FRAMELOCK_TEST_SIGNAL_DISABLE: Final = 0
NV_CTRL_FRAMELOCK_TEST_SIGNAL_ENABLE: Final = 1
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED: Final = 33
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED_NONE: Final = 0
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED_PORT0: Final = 0x1
NV_CTRL_FRAMELOCK_ETHERNET_DETECTED_PORT1: Final = 0x2
NV_CTRL_FRAMELOCK_VIDEO_MODE: Final = 34
NV_CTRL_FRAMELOCK_VIDEO_MODE_NONE: Final = 0
NV_CTRL_FRAMELOCK_VIDEO_MODE_TTL: Final = 1
NV_CTRL_FRAMELOCK_VIDEO_MODE_NTSCPALSECAM: Final = 2
NV_CTRL_FRAMELOCK_VIDEO_MODE_HDTV: Final = 3
NV_CTRL_FRAMELOCK_VIDEO_MODE_COMPOSITE_AUTO: Final = 0
NV_CTRL_FRAMELOCK_VIDEO_MODE_COMPOSITE_BI_LEVEL: Final = 2
NV_CTRL_FRAMELOCK_VIDEO_MODE_COMPOSITE_TRI_LEVEL: Final = 3
NV_CTRL_FRAMELOCK_SYNC_RATE: Final = 35
NV_CTRL_FORCE_GENERIC_CPU: Final = 37
NV_CTRL_FORCE_GENERIC_CPU_DISABLE: Final = 0
NV_CTRL_FORCE_GENERIC_CPU_ENABLE: Final = 1
NV_CTRL_OPENGL_AA_LINE_GAMMA: Final = 38
NV_CTRL_OPENGL_AA_LINE_GAMMA_DISABLE: Final = 0
NV_CTRL_OPENGL_AA_LINE_GAMMA_ENABLE: Final = 1
NV_CTRL_FRAMELOCK_TIMING: Final = 39
NV_CTRL_FRAMELOCK_TIMING_FALSE: Final = 0
NV_CTRL_FRAMELOCK_TIMING_TRUE: Final = 1
NV_CTRL_FLIPPING_ALLOWED: Final = 40
NV_CTRL_FLIPPING_ALLOWED_FALSE: Final = 0
NV_CTRL_FLIPPING_ALLOWED_TRUE: Final = 1
NV_CTRL_ARCHITECTURE: Final = 41
NV_CTRL_ARCHITECTURE_X86: Final = 0
NV_CTRL_ARCHITECTURE_X86_64: Final = 1
NV_CTRL_ARCHITECTURE_IA64: Final = 2
NV_CTRL_ARCHITECTURE_ARM: Final = 3
NV_CTRL_ARCHITECTURE_AARCH64: Final = 4
NV_CTRL_ARCHITECTURE_PPC64LE: Final = 5
NV_CTRL_TEXTURE_CLAMPING: Final = 42
NV_CTRL_TEXTURE_CLAMPING_EDGE: Final = 0
NV_CTRL_TEXTURE_CLAMPING_SPEC: Final = 1
NV_CTRL_CURSOR_SHADOW: Final = 43
NV_CTRL_CURSOR_SHADOW_DISABLE: Final = 0
NV_CTRL_CURSOR_SHADOW_ENABLE: Final = 1
NV_CTRL_CURSOR_SHADOW_ALPHA: Final = 44
NV_CTRL_CURSOR_SHADOW_RED: Final = 45
NV_CTRL_CURSOR_SHADOW_GREEN: Final = 46
NV_CTRL_CURSOR_SHADOW_BLUE: Final = 47
NV_CTRL_CURSOR_SHADOW_X_OFFSET: Final = 48
NV_CTRL_CURSOR_SHADOW_Y_OFFSET: Final = 49
NV_CTRL_FSAA_APPLICATION_CONTROLLED: Final = 50
NV_CTRL_FSAA_APPLICATION_CONTROLLED_ENABLED: Final = 1
NV_CTRL_FSAA_APPLICATION_CONTROLLED_DISABLED: Final = 0
NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED: Final = 51
NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED_ENABLED: Final = 1
NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED_DISABLED: Final = 0
NV_CTRL_IMAGE_SHARPENING: Final = 52
NV_CTRL_TV_OVERSCAN: Final = 53
NV_CTRL_TV_FLICKER_FILTER: Final = 54
NV_CTRL_TV_BRIGHTNESS: Final = 55
NV_CTRL_TV_HUE: Final = 56
NV_CTRL_TV_CONTRAST: Final = 57
NV_CTRL_TV_SATURATION: Final = 58
NV_CTRL_TV_RESET_SETTINGS: Final = 59
NV_CTRL_GPU_CORE_TEMPERATURE: Final = 60
NV_CTRL_GPU_CORE_THRESHOLD: Final = 61
NV_CTRL_GPU_DEFAULT_CORE_THRESHOLD: Final = 62
NV_CTRL_GPU_MAX_CORE_THRESHOLD: Final = 63
NV_CTRL_AMBIENT_TEMPERATURE: Final = 64
NV_CTRL_PBUFFER_SCANOUT_SUPPORTED: Final = 65
NV_CTRL_PBUFFER_SCANOUT_FALSE: Final = 0
NV_CTRL_PBUFFER_SCANOUT_TRUE: Final = 1
NV_CTRL_PBUFFER_SCANOUT_XID: Final = 66
NV_CTRL_GVO_SUPPORTED: Final = 67
NV_CTRL_GVO_SUPPORTED_FALSE: Final = 0
NV_CTRL_GVO_SUPPORTED_TRUE: Final = 1
NV_CTRL_GVO_SYNC_MODE: Final = 68
NV_CTRL_GVO_SYNC_MODE_FREE_RUNNING: Final = 0
NV_CTRL_GVO_SYNC_MODE_GENLOCK: Final = 1
NV_CTRL_GVO_SYNC_MODE_FRAMELOCK: Final = 2
NV_CTRL_GVO_SYNC_SOURCE: Final = 69
NV_CTRL_GVO_SYNC_SOURCE_COMPOSITE: Final = 0
NV_CTRL_GVO_SYNC_SOURCE_SDI: Final = 1
NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT: Final = 70
NV_CTRL_GVIO_VIDEO_FORMAT_NONE: Final = 0
NV_CTRL_GVIO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC: Final = 1
NV_CTRL_GVIO_VIDEO_FORMAT_576I_50_00_SMPTE259_PAL: Final = 2
NV_CTRL_GVIO_VIDEO_FORMAT_720P_59_94_SMPTE296: Final = 3
NV_CTRL_GVIO_VIDEO_FORMAT_720P_60_00_SMPTE296: Final = 4
NV_CTRL_GVIO_VIDEO_FORMAT_1035I_59_94_SMPTE260: Final = 5
NV_CTRL_GVIO_VIDEO_FORMAT_1035I_60_00_SMPTE260: Final = 6
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_50_00_SMPTE295: Final = 7
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_50_00_SMPTE274: Final = 8
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_59_94_SMPTE274: Final = 9
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_60_00_SMPTE274: Final = 10
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_23_976_SMPTE274: Final = 11
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_24_00_SMPTE274: Final = 12
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_25_00_SMPTE274: Final = 13
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_29_97_SMPTE274: Final = 14
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_30_00_SMPTE274: Final = 15
NV_CTRL_GVIO_VIDEO_FORMAT_720P_50_00_SMPTE296: Final = 16
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_48_00_SMPTE274: Final = 17
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_47_96_SMPTE274: Final = 18
NV_CTRL_GVIO_VIDEO_FORMAT_720P_30_00_SMPTE296: Final = 19
NV_CTRL_GVIO_VIDEO_FORMAT_720P_29_97_SMPTE296: Final = 20
NV_CTRL_GVIO_VIDEO_FORMAT_720P_25_00_SMPTE296: Final = 21
NV_CTRL_GVIO_VIDEO_FORMAT_720P_24_00_SMPTE296: Final = 22
NV_CTRL_GVIO_VIDEO_FORMAT_720P_23_98_SMPTE296: Final = 23
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_25_00_SMPTE274: Final = 24
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_29_97_SMPTE274: Final = 25
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_30_00_SMPTE274: Final = 26
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274: Final = 27
NV_CTRL_GVIO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274: Final = 28
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_30_00_SMPTE372: Final = 29
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_29_97_SMPTE372: Final = 30
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_60_00_SMPTE372: Final = 31
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_59_94_SMPTE372: Final = 32
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_25_00_SMPTE372: Final = 33
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_50_00_SMPTE372: Final = 34
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_24_00_SMPTE372: Final = 35
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_23_98_SMPTE372: Final = 36
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_48_00_SMPTE372: Final = 37
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_47_96_SMPTE372: Final = 38
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_50_00_3G_LEVEL_A_SMPTE274: Final = 39
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_59_94_3G_LEVEL_A_SMPTE274: Final = 40
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_60_00_3G_LEVEL_A_SMPTE274: Final = 41
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_60_00_3G_LEVEL_B_SMPTE274: Final = 42
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_60_00_3G_LEVEL_B_SMPTE274: Final = 43
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_60_00_3G_LEVEL_B_SMPTE372: Final = 44
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_50_00_3G_LEVEL_B_SMPTE274: Final = 45
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_50_00_3G_LEVEL_B_SMPTE274: Final = 46
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_50_00_3G_LEVEL_B_SMPTE372: Final = 47
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_30_00_3G_LEVEL_B_SMPTE274: Final = 48
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_30_00_3G_LEVEL_B_SMPTE372: Final = 49
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_25_00_3G_LEVEL_B_SMPTE274: Final = 50
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_25_00_3G_LEVEL_B_SMPTE372: Final = 51
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_24_00_3G_LEVEL_B_SMPTE274: Final = 52
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_24_00_3G_LEVEL_B_SMPTE372: Final = 53
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_48_00_3G_LEVEL_B_SMPTE274: Final = 54
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_48_00_3G_LEVEL_B_SMPTE372: Final = 55
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_59_94_3G_LEVEL_B_SMPTE274: Final = 56
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_59_94_3G_LEVEL_B_SMPTE274: Final = 57
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_59_94_3G_LEVEL_B_SMPTE372: Final = 58
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_29_97_3G_LEVEL_B_SMPTE274: Final = 59
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_29_97_3G_LEVEL_B_SMPTE372: Final = 60
NV_CTRL_GVIO_VIDEO_FORMAT_1080P_23_98_3G_LEVEL_B_SMPTE274: Final = 61
NV_CTRL_GVIO_VIDEO_FORMAT_2048P_23_98_3G_LEVEL_B_SMPTE372: Final = 62
NV_CTRL_GVIO_VIDEO_FORMAT_1080I_47_96_3G_LEVEL_B_SMPTE274: Final = 63
NV_CTRL_GVIO_VIDEO_FORMAT_2048I_47_96_3G_LEVEL_B_SMPTE372: Final = 64
NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT: Final = 70
NV_CTRL_GVO_VIDEO_FORMAT_NONE: Final = 0
NV_CTRL_GVO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC: Final = 1
NV_CTRL_GVO_VIDEO_FORMAT_576I_50_00_SMPTE259_PAL: Final = 2
NV_CTRL_GVO_VIDEO_FORMAT_720P_59_94_SMPTE296: Final = 3
NV_CTRL_GVO_VIDEO_FORMAT_720P_60_00_SMPTE296: Final = 4
NV_CTRL_GVO_VIDEO_FORMAT_1035I_59_94_SMPTE260: Final = 5
NV_CTRL_GVO_VIDEO_FORMAT_1035I_60_00_SMPTE260: Final = 6
NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE295: Final = 7
NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE274: Final = 8
NV_CTRL_GVO_VIDEO_FORMAT_1080I_59_94_SMPTE274: Final = 9
NV_CTRL_GVO_VIDEO_FORMAT_1080I_60_00_SMPTE274: Final = 10
NV_CTRL_GVO_VIDEO_FORMAT_1080P_23_976_SMPTE274: Final = 11
NV_CTRL_GVO_VIDEO_FORMAT_1080P_24_00_SMPTE274: Final = 12
NV_CTRL_GVO_VIDEO_FORMAT_1080P_25_00_SMPTE274: Final = 13
NV_CTRL_GVO_VIDEO_FORMAT_1080P_29_97_SMPTE274: Final = 14
NV_CTRL_GVO_VIDEO_FORMAT_1080P_30_00_SMPTE274: Final = 15
NV_CTRL_GVO_VIDEO_FORMAT_720P_50_00_SMPTE296: Final = 16
NV_CTRL_GVO_VIDEO_FORMAT_1080I_48_00_SMPTE274: Final = 17
NV_CTRL_GVO_VIDEO_FORMAT_1080I_47_96_SMPTE274: Final = 18
NV_CTRL_GVO_VIDEO_FORMAT_720P_30_00_SMPTE296: Final = 19
NV_CTRL_GVO_VIDEO_FORMAT_720P_29_97_SMPTE296: Final = 20
NV_CTRL_GVO_VIDEO_FORMAT_720P_25_00_SMPTE296: Final = 21
NV_CTRL_GVO_VIDEO_FORMAT_720P_24_00_SMPTE296: Final = 22
NV_CTRL_GVO_VIDEO_FORMAT_720P_23_98_SMPTE296: Final = 23
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_25_00_SMPTE274: Final = 24
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_29_97_SMPTE274: Final = 25
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_30_00_SMPTE274: Final = 26
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274: Final = 27
NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274: Final = 28
NV_CTRL_GVO_VIDEO_FORMAT_2048P_30_00_SMPTE372: Final = 29
NV_CTRL_GVO_VIDEO_FORMAT_2048P_29_97_SMPTE372: Final = 30
NV_CTRL_GVO_VIDEO_FORMAT_2048I_60_00_SMPTE372: Final = 31
NV_CTRL_GVO_VIDEO_FORMAT_2048I_59_94_SMPTE372: Final = 32
NV_CTRL_GVO_VIDEO_FORMAT_2048P_25_00_SMPTE372: Final = 33
NV_CTRL_GVO_VIDEO_FORMAT_2048I_50_00_SMPTE372: Final = 34
NV_CTRL_GVO_VIDEO_FORMAT_2048P_24_00_SMPTE372: Final = 35
NV_CTRL_GVO_VIDEO_FORMAT_2048P_23_98_SMPTE372: Final = 36
NV_CTRL_GVO_VIDEO_FORMAT_2048I_48_00_SMPTE372: Final = 37
NV_CTRL_GVO_VIDEO_FORMAT_2048I_47_96_SMPTE372: Final = 38
NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT: Final = 71
NV_CTRL_GVO_INPUT_VIDEO_FORMAT: Final = 71
NV_CTRL_GVO_DATA_FORMAT: Final = 72
NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB444: Final = 0
NV_CTRL_GVO_DATA_FORMAT_R8G8B8A8_TO_YCRCBA4444: Final = 1
NV_CTRL_GVO_DATA_FORMAT_R8G8B8Z10_TO_YCRCBZ4444: Final = 2
NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB422: Final = 3
NV_CTRL_GVO_DATA_FORMAT_R8G8B8A8_TO_YCRCBA4224: Final = 4
NV_CTRL_GVO_DATA_FORMAT_R8G8B8Z10_TO_YCRCBZ4224: Final = 5
NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_RGB444: Final = 6
NV_CTRL_GVO_DATA_FORMAT_X8X8X8_444_PASSTHRU: Final = 6
NV_CTRL_GVO_DATA_FORMAT_R8G8B8A8_TO_RGBA4444: Final = 7
NV_CTRL_GVO_DATA_FORMAT_X8X8X8A8_4444_PASSTHRU: Final = 7
NV_CTRL_GVO_DATA_FORMAT_R8G8B8Z10_TO_RGBZ4444: Final = 8
NV_CTRL_GVO_DATA_FORMAT_X8X8X8Z8_4444_PASSTHRU: Final = 8
NV_CTRL_GVO_DATA_FORMAT_Y10CR10CB10_TO_YCRCB444: Final = 9
NV_CTRL_GVO_DATA_FORMAT_X10X10X10_444_PASSTHRU: Final = 9
NV_CTRL_GVO_DATA_FORMAT_Y10CR8CB8_TO_YCRCB444: Final = 10
NV_CTRL_GVO_DATA_FORMAT_X10X8X8_444_PASSTHRU: Final = 10
NV_CTRL_GVO_DATA_FORMAT_Y10CR8CB8A10_TO_YCRCBA4444: Final = 11
NV_CTRL_GVO_DATA_FORMAT_X10X8X8A10_4444_PASSTHRU: Final = 11
NV_CTRL_GVO_DATA_FORMAT_Y10CR8CB8Z10_TO_YCRCBZ4444: Final = 12
NV_CTRL_GVO_DATA_FORMAT_X10X8X8Z10_4444_PASSTHRU: Final = 12
NV_CTRL_GVO_DATA_FORMAT_DUAL_R8G8B8_TO_DUAL_YCRCB422: Final = 13
NV_CTRL_GVO_DATA_FORMAT_DUAL_Y8CR8CB8_TO_DUAL_YCRCB422: Final = 14
NV_CTRL_GVO_DATA_FORMAT_DUAL_X8X8X8_TO_DUAL_422_PASSTHRU: Final = 14
NV_CTRL_GVO_DATA_FORMAT_R10G10B10_TO_YCRCB422: Final = 15
NV_CTRL_GVO_DATA_FORMAT_R10G10B10_TO_YCRCB444: Final = 16
NV_CTRL_GVO_DATA_FORMAT_Y12CR12CB12_TO_YCRCB444: Final = 17
NV_CTRL_GVO_DATA_FORMAT_X12X12X12_444_PASSTHRU: Final = 17
NV_CTRL_GVO_DATA_FORMAT_R12G12B12_TO_YCRCB444: Final = 18
NV_CTRL_GVO_DATA_FORMAT_X8X8X8_422_PASSTHRU: Final = 19
NV_CTRL_GVO_DATA_FORMAT_X8X8X8A8_4224_PASSTHRU: Final = 20
NV_CTRL_GVO_DATA_FORMAT_X8X8X8Z8_4224_PASSTHRU: Final = 21
NV_CTRL_GVO_DATA_FORMAT_X10X10X10_422_PASSTHRU: Final = 22
NV_CTRL_GVO_DATA_FORMAT_X10X8X8_422_PASSTHRU: Final = 23
NV_CTRL_GVO_DATA_FORMAT_X10X8X8A10_4224_PASSTHRU: Final = 24
NV_CTRL_GVO_DATA_FORMAT_X10X8X8Z10_4224_PASSTHRU: Final = 25
NV_CTRL_GVO_DATA_FORMAT_X12X12X12_422_PASSTHRU: Final = 26
NV_CTRL_GVO_DATA_FORMAT_R12G12B12_TO_YCRCB422: Final = 27
NV_CTRL_GVO_DISPLAY_X_SCREEN: Final = 73
NV_CTRL_GVO_DISPLAY_X_SCREEN_ENABLE: Final = 1
NV_CTRL_GVO_DISPLAY_X_SCREEN_DISABLE: Final = 0
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED: Final = 74
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED_FALSE: Final = 0
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED_TRUE: Final = 1
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE: Final = 75
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE_AUTO: Final = 0
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE_BI_LEVEL: Final = 1
NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE_TRI_LEVEL: Final = 2
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED: Final = 76
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED_NONE: Final = 0
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED_HD: Final = 1
NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED_SD: Final = 2
NV_CTRL_GVO_VIDEO_OUTPUTS: Final = 77
NV_CTRL_GVO_VIDEO_OUTPUTS_NONE: Final = 0
NV_CTRL_GVO_VIDEO_OUTPUTS_VIDEO1: Final = 1
NV_CTRL_GVO_VIDEO_OUTPUTS_VIDEO2: Final = 2
NV_CTRL_GVO_VIDEO_OUTPUTS_VIDEO_BOTH: Final = 3
NV_CTRL_GVO_FIRMWARE_VERSION: Final = 78
NV_CTRL_GVO_SYNC_DELAY_PIXELS: Final = 79
NV_CTRL_GVO_SYNC_DELAY_LINES: Final = 80
NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE: Final = 81
NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE_FALSE: Final = 0
NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE_TRUE: Final = 1
NV_CTRL_GVO_GLX_LOCKED: Final = 82
NV_CTRL_GVO_GLX_LOCKED_FALSE: Final = 0
NV_CTRL_GVO_GLX_LOCKED_TRUE: Final = 1
NV_CTRL_GVIO_VIDEO_FORMAT_WIDTH: Final = 83
NV_CTRL_GVIO_VIDEO_FORMAT_HEIGHT: Final = 84
NV_CTRL_GVIO_VIDEO_FORMAT_REFRESH_RATE: Final = 85
NV_CTRL_GVO_VIDEO_FORMAT_WIDTH: Final = 83
NV_CTRL_GVO_VIDEO_FORMAT_HEIGHT: Final = 84
NV_CTRL_GVO_VIDEO_FORMAT_REFRESH_RATE: Final = 85
NV_CTRL_GVO_X_SCREEN_PAN_X: Final = 86
NV_CTRL_GVO_X_SCREEN_PAN_Y: Final = 87
NV_CTRL_GPU_OVERCLOCKING_STATE: Final = 88
NV_CTRL_GPU_OVERCLOCKING_STATE_NONE: Final = 0
NV_CTRL_GPU_OVERCLOCKING_STATE_MANUAL: Final = 1
NV_CTRL_GPU_2D_CLOCK_FREQS: Final = 89
NV_CTRL_GPU_3D_CLOCK_FREQS: Final = 90
NV_CTRL_GPU_DEFAULT_2D_CLOCK_FREQS: Final = 91
NV_CTRL_GPU_DEFAULT_3D_CLOCK_FREQS: Final = 92
NV_CTRL_GPU_CURRENT_CLOCK_FREQS: Final = 93
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS: Final = 94
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_INVALID: Final = 0
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION: Final = 95
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_START: Final = 0
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_CANCEL: Final = 1
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE: Final = 96
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE_IDLE: Final = 0
NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE_BUSY: Final = 1
NV_CTRL_FLATPANEL_CHIP_LOCATION: Final = 215
NV_CTRL_FLATPANEL_CHIP_LOCATION_INTERNAL: Final = 0
NV_CTRL_FLATPANEL_CHIP_LOCATION_EXTERNAL: Final = 1
NV_CTRL_FLATPANEL_LINK: Final = 216
NV_CTRL_FLATPANEL_LINK_SINGLE: Final = 0
NV_CTRL_FLATPANEL_LINK_DUAL: Final = 1
NV_CTRL_FLATPANEL_LINK_QUAD: Final = 3
NV_CTRL_FLATPANEL_SIGNAL: Final = 217
NV_CTRL_FLATPANEL_SIGNAL_LVDS: Final = 0
NV_CTRL_FLATPANEL_SIGNAL_TMDS: Final = 1
NV_CTRL_FLATPANEL_SIGNAL_DISPLAYPORT: Final = 2
NV_CTRL_USE_HOUSE_SYNC: Final = 218
NV_CTRL_USE_HOUSE_SYNC_DISABLED: Final = 0
NV_CTRL_USE_HOUSE_SYNC_INPUT: Final = 1
NV_CTRL_USE_HOUSE_SYNC_OUTPUT: Final = 2
NV_CTRL_USE_HOUSE_SYNC_FALSE: Final = 0
NV_CTRL_USE_HOUSE_SYNC_TRUE: Final = 1
NV_CTRL_EDID_AVAILABLE: Final = 219
NV_CTRL_EDID_AVAILABLE_FALSE: Final = 0
NV_CTRL_EDID_AVAILABLE_TRUE: Final = 1
NV_CTRL_FORCE_STEREO: Final = 220
NV_CTRL_FORCE_STEREO_FALSE: Final = 0
NV_CTRL_FORCE_STEREO_TRUE: Final = 1
NV_CTRL_IMAGE_SETTINGS: Final = 221
NV_CTRL_IMAGE_SETTINGS_HIGH_QUALITY: Final = 0
NV_CTRL_IMAGE_SETTINGS_QUALITY: Final = 1
NV_CTRL_IMAGE_SETTINGS_PERFORMANCE: Final = 2
NV_CTRL_IMAGE_SETTINGS_HIGH_PERFORMANCE: Final = 3
NV_CTRL_XINERAMA: Final = 222
NV_CTRL_XINERAMA_OFF: Final = 0
NV_CTRL_XINERAMA_ON: Final = 1
NV_CTRL_XINERAMA_STEREO: Final = 223
NV_CTRL_XINERAMA_STEREO_FALSE: Final = 0
NV_CTRL_XINERAMA_STEREO_TRUE: Final = 1
NV_CTRL_BUS_RATE: Final = 224
NV_CTRL_GPU_PCIE_MAX_LINK_WIDTH: Final = NV_CTRL_BUS_RATE
NV_CTRL_SHOW_SLI_VISUAL_INDICATOR: Final = 225
NV_CTRL_SHOW_SLI_VISUAL_INDICATOR_FALSE: Final = 0
NV_CTRL_SHOW_SLI_VISUAL_INDICATOR_TRUE: Final = 1
NV_CTRL_SHOW_SLI_HUD: Final = NV_CTRL_SHOW_SLI_VISUAL_INDICATOR
NV_CTRL_SHOW_SLI_HUD_FALSE: Final = NV_CTRL_SHOW_SLI_VISUAL_INDICATOR_FALSE
NV_CTRL_SHOW_SLI_HUD_TRUE: Final = NV_CTRL_SHOW_SLI_VISUAL_INDICATOR_TRUE
NV_CTRL_XV_SYNC_TO_DISPLAY: Final = 226
NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT2: Final = 227
NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT2: Final = 227
NV_CTRL_GVO_OVERRIDE_HW_CSC: Final = 228
NV_CTRL_GVO_OVERRIDE_HW_CSC_FALSE: Final = 0
NV_CTRL_GVO_OVERRIDE_HW_CSC_TRUE: Final = 1
NV_CTRL_GVO_CAPABILITIES: Final = 229
NV_CTRL_GVO_CAPABILITIES_APPLY_CSC_IMMEDIATELY: Final = 0x00000001
NV_CTRL_GVO_CAPABILITIES_APPLY_CSC_TO_X_SCREEN: Final = 0x00000002
NV_CTRL_GVO_CAPABILITIES_COMPOSITE_TERMINATION: Final = 0x00000004
NV_CTRL_GVO_CAPABILITIES_SHARED_SYNC_BNC: Final = 0x00000008
NV_CTRL_GVO_CAPABILITIES_MULTIRATE_SYNC: Final = 0x00000010
NV_CTRL_GVO_CAPABILITIES_ADVANCE_SYNC_SKEW: Final = 0x00000020
NV_CTRL_GVO_COMPOSITE_TERMINATION: Final = 230
NV_CTRL_GVO_COMPOSITE_TERMINATION_ENABLE: Final = 1
NV_CTRL_GVO_COMPOSITE_TERMINATION_DISABLE: Final = 0
NV_CTRL_ASSOCIATED_DISPLAY_DEVICES: Final = 231
NV_CTRL_FRAMELOCK_SLAVES: Final = 232
NV_CTRL_FRAMELOCK_MASTERABLE: Final = 233
NV_CTRL_PROBE_DISPLAYS: Final = 234
NV_CTRL_REFRESH_RATE: Final = 235
NV_CTRL_GVO_FLIP_QUEUE_SIZE: Final = 236
NV_CTRL_CURRENT_SCANLINE: Final = 237
NV_CTRL_INITIAL_PIXMAP_PLACEMENT: Final = 238
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_FORCE_SYSMEM: Final = 0
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_SYSMEM: Final = 1
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_VIDMEM: Final = 2
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_RESERVED: Final = 3
NV_CTRL_INITIAL_PIXMAP_PLACEMENT_GPU_SYSMEM: Final = 4
NV_CTRL_PCI_BUS: Final = 239
NV_CTRL_PCI_DEVICE: Final = 240
NV_CTRL_PCI_FUNCTION: Final = 241
NV_CTRL_FRAMELOCK_FPGA_REVISION: Final = 242
NV_CTRL_MAX_SCREEN_WIDTH: Final = 243
NV_CTRL_MAX_SCREEN_HEIGHT: Final = 244
NV_CTRL_MAX_DISPLAYS: Final = 245
NV_CTRL_DYNAMIC_TWINVIEW: Final = 246
NV_CTRL_MULTIGPU_DISPLAY_OWNER: Final = 247
NV_CTRL_GPU_SCALING: Final = 248
NV_CTRL_GPU_SCALING_TARGET_INVALID: Final = 0
NV_CTRL_GPU_SCALING_TARGET_FLATPANEL_BEST_FIT: Final = 1
NV_CTRL_GPU_SCALING_TARGET_FLATPANEL_NATIVE: Final = 2
NV_CTRL_GPU_SCALING_METHOD_INVALID: Final = 0
NV_CTRL_GPU_SCALING_METHOD_STRETCHED: Final = 1
NV_CTRL_GPU_SCALING_METHOD_CENTERED: Final = 2
NV_CTRL_GPU_SCALING_METHOD_ASPECT_SCALED: Final = 3
NV_CTRL_FRONTEND_RESOLUTION: Final = 249
NV_CTRL_BACKEND_RESOLUTION: Final = 250
NV_CTRL_FLATPANEL_NATIVE_RESOLUTION: Final = 251
NV_CTRL_FLATPANEL_BEST_FIT_RESOLUTION: Final = 252
NV_CTRL_GPU_SCALING_ACTIVE: Final = 253
NV_CTRL_DFP_SCALING_ACTIVE: Final = 254
NV_CTRL_FSAA_APPLICATION_ENHANCED: Final = 255
NV_CTRL_FSAA_APPLICATION_ENHANCED_ENABLED: Final = 1
NV_CTRL_FSAA_APPLICATION_ENHANCED_DISABLED: Final = 0
NV_CTRL_FRAMELOCK_SYNC_RATE_4: Final = 256
NV_CTRL_GVO_LOCK_OWNER: Final = 257
NV_CTRL_GVO_LOCK_OWNER_NONE: Final = 0
NV_CTRL_GVO_LOCK_OWNER_GLX: Final = 1
NV_CTRL_GVO_LOCK_OWNER_CLONE: Final = 2
NV_CTRL_GVO_LOCK_OWNER_X_SCREEN: Final = 3
NV_CTRL_HWOVERLAY: Final = 258
NV_CTRL_HWOVERLAY_FALSE: Final = 0
NV_CTRL_HWOVERLAY_TRUE: Final = 1
NV_CTRL_NUM_GPU_ERRORS_RECOVERED: Final = 259
NV_CTRL_REFRESH_RATE_3: Final = 260
NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS: Final = 261
NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS_OFF: Final = 0
NV_CTRL_ONDEMAND_VBLANK_INTERRUPTS_ON: Final = 1
NV_CTRL_GPU_POWER_SOURCE: Final = 262
NV_CTRL_GPU_POWER_SOURCE_AC: Final = 0
NV_CTRL_GPU_POWER_SOURCE_BATTERY: Final = 1
NV_CTRL_GPU_CURRENT_PERFORMANCE_MODE: Final = 263
NV_CTRL_GPU_CURRENT_PERFORMANCE_MODE_DESKTOP: Final = 0
NV_CTRL_GPU_CURRENT_PERFORMANCE_MODE_MAXPERF: Final = 1
NV_CTRL_GLYPH_CACHE: Final = 264
NV_CTRL_GLYPH_CACHE_DISABLED: Final = 0
NV_CTRL_GLYPH_CACHE_ENABLED: Final = 1
NV_CTRL_GPU_CURRENT_PERFORMANCE_LEVEL: Final = 265
NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE: Final = 266
NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE_DISABLED: Final = 0
NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE_ENABLED: Final = 1
NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED: Final = 267
NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED_FALSE: Final = 0
NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED_TRUE: Final = 1
NV_CTRL_GVO_SYNC_LOCK_STATUS: Final = 268
NV_CTRL_GVO_SYNC_LOCK_STATUS_UNLOCKED: Final = 0
NV_CTRL_GVO_SYNC_LOCK_STATUS_LOCKED: Final = 1
NV_CTRL_GVO_ANC_TIME_CODE_GENERATION: Final = 269
NV_CTRL_GVO_ANC_TIME_CODE_GENERATION_DISABLE: Final = 0
NV_CTRL_GVO_ANC_TIME_CODE_GENERATION_ENABLE: Final = 1
NV_CTRL_GVO_COMPOSITE: Final = 270
NV_CTRL_GVO_COMPOSITE_DISABLE: Final = 0
NV_CTRL_GVO_COMPOSITE_ENABLE: Final = 1
NV_CTRL_GVO_COMPOSITE_ALPHA_KEY: Final = 271
NV_CTRL_GVO_COMPOSITE_ALPHA_KEY_DISABLE: Final = 0
NV_CTRL_GVO_COMPOSITE_ALPHA_KEY_ENABLE: Final = 1
NV_CTRL_GVO_COMPOSITE_LUMA_KEY_RANGE: Final = 272
NV_CTRL_GVO_COMPOSITE_CR_KEY_RANGE: Final = 273
NV_CTRL_GVO_COMPOSITE_CB_KEY_RANGE: Final = 274
NV_CTRL_GVO_COMPOSITE_NUM_KEY_RANGES: Final = 275
NV_CTRL_SWITCH_TO_DISPLAYS: Final = 276
NV_CTRL_NOTEBOOK_DISPLAY_CHANGE_LID_EVENT: Final = 277
NV_CTRL_NOTEBOOK_INTERNAL_LCD: Final = 278
NV_CTRL_DEPTH_30_ALLOWED: Final = 279
NV_CTRL_MODE_SET_EVENT: Final = 280
NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE: Final = 281
NV_CTRL_VCSC_HIGH_PERF_MODE: Final = 282
NV_CTRL_VCSC_HIGH_PERF_MODE_DISABLE: Final = 0
NV_CTRL_VCSC_HIGH_PERF_MODE_ENABLE: Final = 1
NV_CTRL_DISPLAYPORT_LINK_RATE: Final = 291
NV_CTRL_DISPLAYPORT_LINK_RATE_DISABLED: Final = 0x0
NV_CTRL_DISPLAYPORT_LINK_RATE_1_62GBPS: Final = 0x6
NV_CTRL_DISPLAYPORT_LINK_RATE_2_70GBPS: Final = 0xA
NV_CTRL_STEREO_EYES_EXCHANGE: Final = 292
NV_CTRL_STEREO_EYES_EXCHANGE_OFF: Final = 0
NV_CTRL_STEREO_EYES_EXCHANGE_ON: Final = 1
NV_CTRL_NO_SCANOUT: Final = 293
NV_CTRL_NO_SCANOUT_DISABLED: Final = 0
NV_CTRL_NO_SCANOUT_ENABLED: Final = 1
NV_CTRL_GVO_CSC_CHANGED_EVENT: Final = 294
NV_CTRL_FRAMELOCK_SLAVEABLE: Final = 295
NV_CTRL_GVO_SYNC_TO_DISPLAY: Final = 296
NV_CTRL_GVO_SYNC_TO_DISPLAY_DISABLE: Final = 0
NV_CTRL_GVO_SYNC_TO_DISPLAY_ENABLE: Final = 1
NV_CTRL_X_SERVER_UNIQUE_ID: Final = 297
NV_CTRL_PIXMAP_CACHE: Final = 298
NV_CTRL_PIXMAP_CACHE_DISABLE: Final = 0
NV_CTRL_PIXMAP_CACHE_ENABLE: Final = 1
NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB: Final = 299
NV_CTRL_IS_GVO_DISPLAY: Final = 300
NV_CTRL_IS_GVO_DISPLAY_FALSE: Final = 0
NV_CTRL_IS_GVO_DISPLAY_TRUE: Final = 1
NV_CTRL_PCI_ID: Final = 301
NV_CTRL_GVO_FULL_RANGE_COLOR: Final = 302
NV_CTRL_GVO_FULL_RANGE_COLOR_DISABLED: Final = 0
NV_CTRL_GVO_FULL_RANGE_COLOR_ENABLED: Final = 1
NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE: Final = 303
NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE_FALSE: Final = 0
NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE_TRUE: Final = 1
NV_CTRL_GVO_ENABLE_RGB_DATA: Final = 304
NV_CTRL_GVO_ENABLE_RGB_DATA_DISABLE: Final = 0
NV_CTRL_GVO_ENABLE_RGB_DATA_ENABLE: Final = 1
NV_CTRL_IMAGE_SHARPENING_DEFAULT: Final = 305
NV_CTRL_PCI_DOMAIN: Final = 306
NV_CTRL_GVI_NUM_JACKS: Final = 307
NV_CTRL_GVI_MAX_LINKS_PER_STREAM: Final = 308
NV_CTRL_GVI_DETECTED_CHANNEL_BITS_PER_COMPONENT: Final = 309
NV_CTRL_GVI_BITS_PER_COMPONENT_UNKNOWN: Final = 0
NV_CTRL_GVI_BITS_PER_COMPONENT_8: Final = 1
NV_CTRL_GVI_BITS_PER_COMPONENT_10: Final = 2
NV_CTRL_GVI_BITS_PER_COMPONENT_12: Final = 3
NV_CTRL_GVI_REQUESTED_STREAM_BITS_PER_COMPONENT: Final = 310
NV_CTRL_GVI_DETECTED_CHANNEL_COMPONENT_SAMPLING: Final = 311
NV_CTRL_GVI_COMPONENT_SAMPLING_UNKNOWN: Final = 0
NV_CTRL_GVI_COMPONENT_SAMPLING_4444: Final = 1
NV_CTRL_GVI_COMPONENT_SAMPLING_4224: Final = 2
NV_CTRL_GVI_COMPONENT_SAMPLING_444: Final = 3
NV_CTRL_GVI_COMPONENT_SAMPLING_422: Final = 4
NV_CTRL_GVI_COMPONENT_SAMPLING_420: Final = 5
NV_CTRL_GVI_REQUESTED_STREAM_COMPONENT_SAMPLING: Final = 312
NV_CTRL_GVI_REQUESTED_STREAM_CHROMA_EXPAND: Final = 313
NV_CTRL_GVI_CHROMA_EXPAND_FALSE: Final = 0
NV_CTRL_GVI_CHROMA_EXPAND_TRUE: Final = 1
NV_CTRL_GVI_DETECTED_CHANNEL_COLOR_SPACE: Final = 314
NV_CTRL_GVI_COLOR_SPACE_UNKNOWN: Final = 0
NV_CTRL_GVI_COLOR_SPACE_GBR: Final = 1
NV_CTRL_GVI_COLOR_SPACE_GBRA: Final = 2
NV_CTRL_GVI_COLOR_SPACE_GBRD: Final = 3
NV_CTRL_GVI_COLOR_SPACE_YCBCR: Final = 4
NV_CTRL_GVI_COLOR_SPACE_YCBCRA: Final = 5
NV_CTRL_GVI_COLOR_SPACE_YCBCRD: Final = 6
NV_CTRL_GVI_DETECTED_CHANNEL_LINK_ID: Final = 315
NV_CTRL_GVI_LINK_ID_UNKNOWN: Final = 0xFFFF
NV_CTRL_GVI_DETECTED_CHANNEL_SMPTE352_IDENTIFIER: Final = 316
NV_CTRL_GVI_GLOBAL_IDENTIFIER: Final = 317
NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION: Final = 318
NV_CTRL_GPU_COOLER_MANUAL_CONTROL: Final = 319
NV_CTRL_GPU_COOLER_MANUAL_CONTROL_FALSE: Final = 0
NV_CTRL_GPU_COOLER_MANUAL_CONTROL_TRUE: Final = 1
NV_CTRL_THERMAL_COOLER_LEVEL: Final = 320
NV_CTRL_THERMAL_COOLER_LEVEL_SET_DEFAULT: Final = 321
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE: Final = 322
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE_NONE: Final = 0
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE_TOGGLE: Final = 1
NV_CTRL_THERMAL_COOLER_CONTROL_TYPE_VARIABLE: Final = 2
NV_CTRL_THERMAL_COOLER_TARGET: Final = 323
NV_CTRL_THERMAL_COOLER_TARGET_NONE: Final = 0
NV_CTRL_THERMAL_COOLER_TARGET_GPU: Final = 1
NV_CTRL_THERMAL_COOLER_TARGET_MEMORY: Final = 2
NV_CTRL_THERMAL_COOLER_TARGET_POWER_SUPPLY: Final = 4
NV_CTRL_THERMAL_COOLER_TARGET_GPU_RELATED: Final = 7
NV_CTRL_GPU_ECC_SUPPORTED: Final = 324
NV_CTRL_GPU_ECC_SUPPORTED_FALSE: Final = 0
NV_CTRL_GPU_ECC_SUPPORTED_TRUE: Final = 1
NV_CTRL_GPU_ECC_STATUS: Final = 325
NV_CTRL_GPU_ECC_STATUS_DISABLED: Final = 0
NV_CTRL_GPU_ECC_STATUS_ENABLED: Final = 1
NV_CTRL_GPU_ECC_CONFIGURATION_SUPPORTED: Final = 326
NV_CTRL_GPU_ECC_CONFIGURATION_SUPPORTED_FALSE: Final = 0
NV_CTRL_GPU_ECC_CONFIGURATION_SUPPORTED_TRUE: Final = 1
NV_CTRL_GPU_ECC_CONFIGURATION: Final = 327
NV_CTRL_GPU_ECC_CONFIGURATION_DISABLED: Final = 0
NV_CTRL_GPU_ECC_CONFIGURATION_ENABLED: Final = 1
NV_CTRL_GPU_ECC_DEFAULT_CONFIGURATION: Final = 328
NV_CTRL_GPU_ECC_DEFAULT_CONFIGURATION_DISABLED: Final = 0
NV_CTRL_GPU_ECC_DEFAULT_CONFIGURATION_ENABLED: Final = 1
NV_CTRL_GPU_ECC_SINGLE_BIT_ERRORS: Final = 329
NV_CTRL_GPU_ECC_DOUBLE_BIT_ERRORS: Final = 330
NV_CTRL_GPU_ECC_AGGREGATE_SINGLE_BIT_ERRORS: Final = 331
NV_CTRL_GPU_ECC_AGGREGATE_DOUBLE_BIT_ERRORS: Final = 332
NV_CTRL_GPU_ECC_RESET_ERROR_STATUS: Final = 333
NV_CTRL_GPU_ECC_RESET_ERROR_STATUS_VOLATILE: Final = 0x00000001
NV_CTRL_GPU_ECC_RESET_ERROR_STATUS_AGGREGATE: Final = 0x00000002
NV_CTRL_GPU_POWER_MIZER_MODE: Final = 334
NV_CTRL_GPU_POWER_MIZER_MODE_ADAPTIVE: Final = 0
NV_CTRL_GPU_POWER_MIZER_MODE_PREFER_MAXIMUM_PERFORMANCE: Final = 1
NV_CTRL_GPU_POWER_MIZER_MODE_AUTO: Final = 2
NV_CTRL_GPU_POWER_MIZER_MODE_PREFER_CONSISTENT_PERFORMANCE: Final = 3
NV_CTRL_GVI_SYNC_OUTPUT_FORMAT: Final = 335
NV_CTRL_GVI_MAX_CHANNELS_PER_JACK: Final = 336
NV_CTRL_GVI_MAX_STREAMS: Final = 337
NV_CTRL_GVI_NUM_CAPTURE_SURFACES: Final = 338
NV_CTRL_OVERSCAN_COMPENSATION: Final = 339
NV_CTRL_GPU_PCIE_GENERATION: Final = 341
NV_CTRL_GPU_PCIE_GENERATION1: Final = 0x00000001
NV_CTRL_GPU_PCIE_GENERATION2: Final = 0x00000002
NV_CTRL_GPU_PCIE_GENERATION3: Final = 0x00000003
NV_CTRL_GVI_BOUND_GPU: Final = 342
NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT3: Final = 343
NV_CTRL_ACCELERATE_TRAPEZOIDS: Final = 344
NV_CTRL_ACCELERATE_TRAPEZOIDS_DISABLE: Final = 0
NV_CTRL_ACCELERATE_TRAPEZOIDS_ENABLE: Final = 1
NV_CTRL_GPU_CORES: Final = 345
NV_CTRL_GPU_MEMORY_BUS_WIDTH: Final = 346
NV_CTRL_GVI_TEST_MODE: Final = 347
NV_CTRL_GVI_TEST_MODE_DISABLE: Final = 0
NV_CTRL_GVI_TEST_MODE_ENABLE: Final = 1
NV_CTRL_COLOR_SPACE: Final = 348
NV_CTRL_COLOR_SPACE_RGB: Final = 0
NV_CTRL_COLOR_SPACE_YCbCr422: Final = 1
NV_CTRL_COLOR_SPACE_YCbCr444: Final = 2
NV_CTRL_COLOR_RANGE: Final = 349
NV_CTRL_COLOR_RANGE_FULL: Final = 0
NV_CTRL_COLOR_RANGE_LIMITED: Final = 1
NV_CTRL_GPU_SCALING_DEFAULT_TARGET: Final = 350
NV_CTRL_GPU_SCALING_DEFAULT_METHOD: Final = 351
NV_CTRL_DITHERING_MODE: Final = 352
NV_CTRL_DITHERING_MODE_AUTO: Final = 0
NV_CTRL_DITHERING_MODE_DYNAMIC_2X2: Final = 1
NV_CTRL_DITHERING_MODE_STATIC_2X2: Final = 2
NV_CTRL_DITHERING_MODE_TEMPORAL: Final = 3
NV_CTRL_CURRENT_DITHERING: Final = 353
NV_CTRL_CURRENT_DITHERING_DISABLED: Final = 0
NV_CTRL_CURRENT_DITHERING_ENABLED: Final = 1
NV_CTRL_CURRENT_DITHERING_MODE: Final = 354
NV_CTRL_CURRENT_DITHERING_MODE_NONE: Final = 0
NV_CTRL_CURRENT_DITHERING_MODE_DYNAMIC_2X2: Final = 1
NV_CTRL_CURRENT_DITHERING_MODE_STATIC_2X2: Final = 2
NV_CTRL_CURRENT_DITHERING_MODE_TEMPORAL: Final = 3
NV_CTRL_THERMAL_SENSOR_READING: Final = 355
NV_CTRL_THERMAL_SENSOR_PROVIDER: Final = 356
NV_CTRL_THERMAL_SENSOR_PROVIDER_NONE: Final = 0
NV_CTRL_THERMAL_SENSOR_PROVIDER_GPU_INTERNAL: Final = 1
NV_CTRL_THERMAL_SENSOR_PROVIDER_ADM1032: Final = 2
NV_CTRL_THERMAL_SENSOR_PROVIDER_ADT7461: Final = 3
NV_CTRL_THERMAL_SENSOR_PROVIDER_MAX6649: Final = 4
NV_CTRL_THERMAL_SENSOR_PROVIDER_MAX1617: Final = 5
NV_CTRL_THERMAL_SENSOR_PROVIDER_LM99: Final = 6
NV_CTRL_THERMAL_SENSOR_PROVIDER_LM89: Final = 7
NV_CTRL_THERMAL_SENSOR_PROVIDER_LM64: Final = 8
NV_CTRL_THERMAL_SENSOR_PROVIDER_G781: Final = 9
NV_CTRL_THERMAL_SENSOR_PROVIDER_ADT7473: Final = 10
NV_CTRL_THERMAL_SENSOR_PROVIDER_SBMAX6649: Final = 11
NV_CTRL_THERMAL_SENSOR_PROVIDER_VBIOSEVT: Final = 12
NV_CTRL_THERMAL_SENSOR_PROVIDER_OS: Final = 13
NV_CTRL_THERMAL_SENSOR_PROVIDER_UNKNOWN: Final = 0xFFFFFFFF
NV_CTRL_THERMAL_SENSOR_TARGET: Final = 357
NV_CTRL_THERMAL_SENSOR_TARGET_NONE: Final = 0
NV_CTRL_THERMAL_SENSOR_TARGET_GPU: Final = 1
NV_CTRL_THERMAL_SENSOR_TARGET_MEMORY: Final = 2
NV_CTRL_THERMAL_SENSOR_TARGET_POWER_SUPPLY: Final = 4
NV_CTRL_THERMAL_SENSOR_TARGET_BOARD: Final = 8
NV_CTRL_THERMAL_SENSOR_TARGET_UNKNOWN: Final = 0xFFFFFFFF
NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR: Final = 358
NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR_FALSE: Final = 0
NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR_TRUE: Final = 1
NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS: Final = 359
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS: Final = 360
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_NONE: Final = 0x00000000
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_INTERLACED: Final = 0x00000001
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_PROGRESSIVE: Final = 0x00000002
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_PSF: Final = 0x00000004
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G_LEVEL_A: Final = 0x00000008
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G_LEVEL_B: Final = 0x00000010
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G: Final = 24
NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS_3G_1080P_NO_12BPC: Final = 0x00000020
NV_CTRL_GPU_PCIE_MAX_LINK_SPEED: Final = 361
NV_CTRL_3D_VISION_PRO_RESET_TRANSCEIVER_TO_FACTORY_SETTINGS: Final = 363
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL: Final = 364
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE: Final = 365
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_INVALID: Final = 0
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_LOW_RANGE: Final = 1
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_MEDIUM_RANGE: Final = 2
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_HIGH_RANGE: Final = 3
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE_COUNT: Final = 4
NV_CTRL_SYNCHRONOUS_PALETTE_UPDATES: Final = 367
NV_CTRL_SYNCHRONOUS_PALETTE_UPDATES_DISABLE: Final = 0
NV_CTRL_SYNCHRONOUS_PALETTE_UPDATES_ENABLE: Final = 1
NV_CTRL_DITHERING_DEPTH: Final = 368
NV_CTRL_DITHERING_DEPTH_AUTO: Final = 0
NV_CTRL_DITHERING_DEPTH_6_BITS: Final = 1
NV_CTRL_DITHERING_DEPTH_8_BITS: Final = 2
NV_CTRL_CURRENT_DITHERING_DEPTH: Final = 369
NV_CTRL_CURRENT_DITHERING_DEPTH_NONE: Final = 0
NV_CTRL_CURRENT_DITHERING_DEPTH_6_BITS: Final = 1
NV_CTRL_CURRENT_DITHERING_DEPTH_8_BITS: Final = 2
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL_FREQUENCY: Final = 370
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL_QUALITY: Final = 371
NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL_COUNT: Final = 372
NV_CTRL_3D_VISION_PRO_PAIR_GLASSES: Final = 373
NV_CTRL_3D_VISION_PRO_PAIR_GLASSES_STOP: Final = 0
NV_CTRL_3D_VISION_PRO_PAIR_GLASSES_BEACON: Final = 0xFFFFFFFF
NV_CTRL_3D_VISION_PRO_UNPAIR_GLASSES: Final = 374
NV_CTRL_3D_VISION_PRO_DISCOVER_GLASSES: Final = 375
NV_CTRL_3D_VISION_PRO_IDENTIFY_GLASSES: Final = 376
NV_CTRL_3D_VISION_PRO_GLASSES_SYNC_CYCLE: Final = 378
NV_CTRL_3D_VISION_PRO_GLASSES_MISSED_SYNC_CYCLES: Final = 379
NV_CTRL_3D_VISION_PRO_GLASSES_BATTERY_LEVEL: Final = 380
NV_CTRL_GVO_ANC_PARITY_COMPUTATION: Final = 381
NV_CTRL_GVO_ANC_PARITY_COMPUTATION_AUTO: Final = 0
NV_CTRL_GVO_ANC_PARITY_COMPUTATION_ON: Final = 1
NV_CTRL_GVO_ANC_PARITY_COMPUTATION_OFF: Final = 2
NV_CTRL_3D_VISION_PRO_GLASSES_PAIR_EVENT: Final = 382
NV_CTRL_3D_VISION_PRO_GLASSES_UNPAIR_EVENT: Final = 383
NV_CTRL_GPU_PCIE_CURRENT_LINK_WIDTH: Final = 384
NV_CTRL_GPU_PCIE_CURRENT_LINK_SPEED: Final = 385
NV_CTRL_GVO_AUDIO_BLANKING: Final = 386
NV_CTRL_GVO_AUDIO_BLANKING_DISABLE: Final = 0
NV_CTRL_GVO_AUDIO_BLANKING_ENABLE: Final = 1
NV_CTRL_CURRENT_METAMODE_ID: Final = 387
NV_CTRL_DISPLAY_ENABLED: Final = 388
NV_CTRL_DISPLAY_ENABLED_TRUE: Final = 1
NV_CTRL_DISPLAY_ENABLED_FALSE: Final = 0
NV_CTRL_FRAMELOCK_INCOMING_HOUSE_SYNC_RATE: Final = 389
NV_CTRL_FXAA: Final = 390
NV_CTRL_FXAA_DISABLE: Final = 0
NV_CTRL_FXAA_ENABLE: Final = 1
NV_CTRL_DISPLAY_RANDR_OUTPUT_ID: Final = 391
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG: Final = 392
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG_DISABLED: Final = 0
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG_CLIENT: Final = 1
NV_CTRL_FRAMELOCK_DISPLAY_CONFIG_SERVER: Final = 2
NV_CTRL_TOTAL_DEDICATED_GPU_MEMORY: Final = 393
NV_CTRL_USED_DEDICATED_GPU_MEMORY: Final = 394
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_IMMEDIATE: Final = 395
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_IMMEDIATE_DISABLED: Final = 0
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_IMMEDIATE_ENABLED: Final = 1
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT: Final = 396
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT_DISABLED: Final = 0
NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT_ENALED: Final = 1
NV_CTRL_DPY_HDMI_3D: Final = 397
NV_CTRL_DPY_HDMI_3D_DISABLED: Final = 0
NV_CTRL_DPY_HDMI_3D_ENABLED: Final = 1
NV_CTRL_BASE_MOSAIC: Final = 398
NV_CTRL_BASE_MOSAIC_DISABLED: Final = 0
NV_CTRL_BASE_MOSAIC_FULL: Final = 1
NV_CTRL_BASE_MOSAIC_LIMITED: Final = 2
NV_CTRL_MULTIGPU_MASTER_POSSIBLE: Final = 399
NV_CTRL_MULTIGPU_MASTER_POSSIBLE_FALSE: Final = 0
NV_CTRL_MULTIGPU_MASTER_POSSIBLE_TRUE: Final = 1
NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE: Final = 400
NV_CTRL_XV_SYNC_TO_DISPLAY_ID: Final = 401
NV_CTRL_XV_SYNC_TO_DISPLAY_ID_AUTO: Final = 0xFFFFFFFF
NV_CTRL_BACKLIGHT_BRIGHTNESS: Final = 402
NV_CTRL_GPU_LOGO_BRIGHTNESS: Final = 403
NV_CTRL_GPU_SLI_LOGO_BRIGHTNESS: Final = 404
NV_CTRL_THERMAL_COOLER_SPEED: Final = 405
NV_CTRL_PALETTE_UPDATE_EVENT: Final = 406
NV_CTRL_VIDEO_ENCODER_UTILIZATION: Final = 407
NV_CTRL_GSYNC_ALLOWED: Final = 408
NV_CTRL_GSYNC_ALLOWED_FALSE: Final = 0
NV_CTRL_GSYNC_ALLOWED_TRUE: Final = 1
NV_CTRL_GPU_NVCLOCK_OFFSET: Final = 409
NV_CTRL_GPU_MEM_TRANSFER_RATE_OFFSET: Final = 410
NV_CTRL_VIDEO_DECODER_UTILIZATION: Final = 411
NV_CTRL_GPU_OVER_VOLTAGE_OFFSET: Final = 412
NV_CTRL_GPU_CURRENT_CORE_VOLTAGE: Final = 413
NV_CTRL_CURRENT_COLOR_SPACE: Final = 414
NV_CTRL_CURRENT_COLOR_SPACE_RGB: Final = 0
NV_CTRL_CURRENT_COLOR_SPACE_YCbCr422: Final = 1
NV_CTRL_CURRENT_COLOR_SPACE_YCbCr444: Final = 2
NV_CTRL_CURRENT_COLOR_SPACE_YCbCr420: Final = 3
NV_CTRL_CURRENT_COLOR_RANGE: Final = 415
NV_CTRL_CURRENT_COLOR_RANGE_FULL: Final = 0
NV_CTRL_CURRENT_COLOR_RANGE_LIMITED: Final = 1
NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR: Final = 416
NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR_FALSE: Final = 0
NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR_TRUE: Final = 1
NV_CTRL_THERMAL_COOLER_CURRENT_LEVEL: Final = 417
NV_CTRL_STEREO_SWAP_MODE: Final = 418
NV_CTRL_STEREO_SWAP_MODE_APPLICATION_CONTROL: Final = 0
NV_CTRL_STEREO_SWAP_MODE_PER_EYE: Final = 1
NV_CTRL_STEREO_SWAP_MODE_PER_EYE_PAIR: Final = 2
NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID: Final = 419
NV_CTRL_GPU_FRAMELOCK_FIRMWARE_UNSUPPORTED: Final = 420
NV_CTRL_GPU_FRAMELOCK_FIRMWARE_UNSUPPORTED_FALSE: Final = 0
NV_CTRL_GPU_FRAMELOCK_FIRMWARE_UNSUPPORTED_TRUE: Final = 1
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE: Final = 421
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_UNKNOWN: Final = 0
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_DISPLAYPORT: Final = 1
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_HDMI: Final = 2
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_DVI: Final = 3
NV_CTRL_DISPLAYPORT_CONNECTOR_TYPE_VGA: Final = 4
NV_CTRL_DISPLAYPORT_IS_MULTISTREAM: Final = 422
NV_CTRL_DISPLAYPORT_SINK_IS_AUDIO_CAPABLE: Final = 423
NV_CTRL_GPU_NVCLOCK_OFFSET_ALL_PERFORMANCE_LEVELS: Final = 424
NV_CTRL_GPU_MEM_TRANSFER_RATE_OFFSET_ALL_PERFORMANCE_LEVELS: Final = 425
NV_CTRL_FRAMELOCK_FIRMWARE_VERSION: Final = 426
NV_CTRL_FRAMELOCK_FIRMWARE_MINOR_VERSION: Final = 427
NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR: Final = 428
NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR_FALSE: Final = 0
NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR_TRUE: Final = 1
NV_CTRL_LAST_ATTRIBUTE: Final = NV_CTRL_SHOW_GRAPHICS_VISUAL_INDICATOR
NV_CTRL_STRING_PRODUCT_NAME: Final = 0
NV_CTRL_STRING_VBIOS_VERSION: Final = 1
NV_CTRL_STRING_NVIDIA_DRIVER_VERSION: Final = 3
NV_CTRL_STRING_DISPLAY_DEVICE_NAME: Final = 4
NV_CTRL_STRING_TV_ENCODER_NAME: Final = 5
NV_CTRL_STRING_GVIO_FIRMWARE_VERSION: Final = 8
NV_CTRL_STRING_GVO_FIRMWARE_VERSION: Final = 8
NV_CTRL_STRING_CURRENT_MODELINE: Final = 9
NV_CTRL_STRING_ADD_MODELINE: Final = 10
NV_CTRL_STRING_DELETE_MODELINE: Final = 11
NV_CTRL_STRING_CURRENT_METAMODE: Final = 12
NV_CTRL_STRING_CURRENT_METAMODE_VERSION_1: Final = NV_CTRL_STRING_CURRENT_METAMODE
NV_CTRL_STRING_ADD_METAMODE: Final = 13
NV_CTRL_STRING_DELETE_METAMODE: Final = 14
NV_CTRL_STRING_VCSC_PRODUCT_NAME: Final = 15
NV_CTRL_STRING_VCSC_PRODUCT_ID: Final = 16
NV_CTRL_STRING_VCSC_SERIAL_NUMBER: Final = 17
NV_CTRL_STRING_VCSC_BUILD_DATE: Final = 18
NV_CTRL_STRING_VCSC_FIRMWARE_VERSION: Final = 19
NV_CTRL_STRING_VCSC_FIRMWARE_REVISION: Final = 20
NV_CTRL_STRING_VCSC_HARDWARE_VERSION: Final = 21
NV_CTRL_STRING_VCSC_HARDWARE_REVISION: Final = 22
NV_CTRL_STRING_MOVE_METAMODE: Final = 23
NV_CTRL_STRING_VALID_HORIZ_SYNC_RANGES: Final = 24
NV_CTRL_STRING_VALID_VERT_REFRESH_RANGES: Final = 25
NV_CTRL_STRING_SCREEN_RECTANGLE: Final = 26
NV_CTRL_STRING_XINERAMA_SCREEN_INFO: Final = 26
NV_CTRL_STRING_NVIDIA_XINERAMA_INFO_ORDER: Final = 27
NV_CTRL_STRING_TWINVIEW_XINERAMA_INFO_ORDER: Final = NV_CTRL_STRING_NVIDIA_XINERAMA_INFO_ORDER
NV_CTRL_STRING_SLI_MODE: Final = 28
NV_CTRL_STRING_PERFORMANCE_MODES: Final = 29
NV_CTRL_STRING_VCSC_FAN_STATUS: Final = 30
NV_CTRL_STRING_VCSC_TEMPERATURES: Final = 31
NV_CTRL_STRING_VCSC_PSU_INFO: Final = 32
NV_CTRL_STRING_GVIO_VIDEO_FORMAT_NAME: Final = 33
NV_CTRL_STRING_GVO_VIDEO_FORMAT_NAME: Final = 33
NV_CTRL_STRING_GPU_CURRENT_CLOCK_FREQS: Final = 34
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_HARDWARE_REVISION: Final = 35
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_VERSION_A: Final = 36
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_DATE_A: Final = 37
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_VERSION_B: Final = 38
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_FIRMWARE_DATE_B: Final = 39
NV_CTRL_STRING_3D_VISION_PRO_TRANSCEIVER_ADDRESS: Final = 40
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_FIRMWARE_VERSION_A: Final = 41
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_FIRMWARE_DATE_A: Final = 42
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_ADDRESS: Final = 43
NV_CTRL_STRING_3D_VISION_PRO_GLASSES_NAME: Final = 44
NV_CTRL_STRING_CURRENT_METAMODE_VERSION_2: Final = 45
NV_CTRL_STRING_DISPLAY_NAME_TYPE_BASENAME: Final = 46
NV_CTRL_STRING_DISPLAY_NAME_TYPE_ID: Final = 47
NV_CTRL_STRING_DISPLAY_NAME_DP_GUID: Final = 48
NV_CTRL_STRING_DISPLAY_NAME_EDID_HASH: Final = 49
NV_CTRL_STRING_DISPLAY_NAME_TARGET_INDEX: Final = 50
NV_CTRL_STRING_DISPLAY_NAME_RANDR: Final = 51
NV_CTRL_STRING_GPU_UUID: Final = 52
NV_CTRL_STRING_GPU_UTILIZATION: Final = 53
NV_CTRL_STRING_MULTIGPU_MODE: Final = 54
NV_CTRL_STRING_PRIME_OUTPUTS_DATA: Final = 55
NV_CTRL_STRING_LAST_ATTRIBUTE: Final = NV_CTRL_STRING_PRIME_OUTPUTS_DATA
NV_CTRL_BINARY_DATA_EDID: Final = 0
NV_CTRL_BINARY_DATA_MODELINES: Final = 1
NV_CTRL_BINARY_DATA_METAMODES: Final = 2
NV_CTRL_BINARY_DATA_METAMODES_VERSION_1: Final = NV_CTRL_BINARY_DATA_METAMODES
NV_CTRL_BINARY_DATA_XSCREENS_USING_GPU: Final = 3
NV_CTRL_BINARY_DATA_GPUS_USED_BY_XSCREEN: Final = 4
NV_CTRL_BINARY_DATA_GPUS_USING_FRAMELOCK: Final = 5
NV_CTRL_BINARY_DATA_DISPLAY_VIEWPORT: Final = 6
NV_CTRL_BINARY_DATA_FRAMELOCKS_USED_BY_GPU: Final = 7
NV_CTRL_BINARY_DATA_GPUS_USING_VCSC: Final = 8
NV_CTRL_BINARY_DATA_VCSCS_USED_BY_GPU: Final = 9
NV_CTRL_BINARY_DATA_COOLERS_USED_BY_GPU: Final = 10
NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN: Final = 11
NV_CTRL_BINARY_DATA_THERMAL_SENSORS_USED_BY_GPU: Final = 12
NV_CTRL_BINARY_DATA_GLASSES_PAIRED_TO_3D_VISION_PRO_TRANSCEIVER: Final = 13
NV_CTRL_BINARY_DATA_DISPLAY_TARGETS: Final = 14
NV_CTRL_BINARY_DATA_DISPLAYS_CONNECTED_TO_GPU: Final = 15
NV_CTRL_BINARY_DATA_METAMODES_VERSION_2: Final = 16
NV_CTRL_BINARY_DATA_DISPLAYS_ENABLED_ON_XSCREEN: Final = 17
NV_CTRL_BINARY_DATA_DISPLAYS_ASSIGNED_TO_XSCREEN: Final = 18
NV_CTRL_BINARY_DATA_GPU_FLAGS: Final = 19
NV_CTRL_BINARY_DATA_GPU_FLAGS_STEREO_DISPLAY_TRANSFORM_EXCLUSIVE: Final = 0
NV_CTRL_BINARY_DATA_GPU_FLAGS_OVERLAY_DISPLAY_TRANSFORM_EXCLUSIVE: Final = 1
NV_CTRL_BINARY_DATA_GPU_FLAGS_DEPTH_8_DISPLAY_TRANSFORM_EXCLUSIVE: Final = 2
NV_CTRL_BINARY_DATA_DISPLAYS_ON_GPU: Final = 20
NV_CTRL_BINARY_DATA_LAST_ATTRIBUTE: Final = NV_CTRL_BINARY_DATA_DISPLAYS_ON_GPU
NV_CTRL_STRING_OPERATION_ADD_METAMODE: Final = 0
NV_CTRL_STRING_OPERATION_GTF_MODELINE: Final = 1
NV_CTRL_STRING_OPERATION_CVT_MODELINE: Final = 2
NV_CTRL_STRING_OPERATION_BUILD_MODEPOOL: Final = 3
NV_CTRL_STRING_OPERATION_GVI_CONFIGURE_STREAMS: Final = 4
NV_CTRL_STRING_OPERATION_PARSE_METAMODE: Final = 5
NV_CTRL_STRING_OPERATION_LAST_ATTRIBUTE: Final = NV_CTRL_STRING_OPERATION_PARSE_METAMODE
X_nvCtrlQueryExtension: Final = 0
X_nvCtrlQueryAttribute: Final = 2
X_nvCtrlQueryStringAttribute: Final = 4
X_nvCtrlQueryValidAttributeValues: Final = 5
X_nvCtrlSetStringAttribute: Final = 9
X_nvCtrlSetAttributeAndGetStatus: Final = 19
X_nvCtrlQueryBinaryData: Final = 20
X_nvCtrlQueryTargetCount: Final = 24
X_nvCtrlStringOperation: Final = 25
ATTRIBUTE_TYPE_UNKNOWN: Final = 0
ATTRIBUTE_TYPE_INTEGER: Final = 1
ATTRIBUTE_TYPE_BITMASK: Final = 2
ATTRIBUTE_TYPE_BOOL: Final = 3
ATTRIBUTE_TYPE_RANGE: Final = 4
ATTRIBUTE_TYPE_INT_BITS: Final = 5
ATTRIBUTE_TYPE_READ: Final = 0x01
ATTRIBUTE_TYPE_WRITE: Final = 0x02
ATTRIBUTE_TYPE_DISPLAY: Final = 0x04
ATTRIBUTE_TYPE_GPU: Final = 0x08
ATTRIBUTE_TYPE_FRAMELOCK: Final = 0x10
ATTRIBUTE_TYPE_X_SCREEN: Final = 0x20
ATTRIBUTE_TYPE_XINERAMA: Final = 0x40
ATTRIBUTE_TYPE_VCSC: Final = 0x80
NV_CTRL_TARGET_TYPE_X_SCREEN: Final = 0
NV_CTRL_TARGET_TYPE_GPU: Final = 1
NV_CTRL_TARGET_TYPE_FRAMELOCK: Final = 2
NV_CTRL_TARGET_TYPE_VCSC: Final = 3
NV_CTRL_TARGET_TYPE_GVI: Final = 4
NV_CTRL_TARGET_TYPE_COOLER: Final = 5
NV_CTRL_TARGET_TYPE_THERMAL_SENSOR: Final = 6
NV_CTRL_TARGET_TYPE_3D_VISION_PRO_TRANSCEIVER: Final = 7
NV_CTRL_TARGET_TYPE_DISPLAY: Final = 8

class Target:
    def id(self) -> int: ...
    def type(self) -> int: ...

class Gpu(Target):
    def __init__(self, ngpu: int = 0) -> None: ...

class Screen(Target):
    def __init__(self, nscr: int = 0) -> None: ...

class Cooler(Target):
    def __init__(self, nfan: int = 0) -> None: ...

class NVCtrlQueryTargetCountReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryAttributeReplyRequest(rq.ReplyRequest): ...
class NVCtrlSetAttributeAndGetStatusReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryStringAttributeReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryValidAttributeValuesReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryBinaryDataReplyRequest(rq.ReplyRequest): ...
class NVCtrlQueryListCard32ReplyRequest(rq.ReplyRequest): ...



"""Meaning Typed Programming constructs for Jac Language."""

from collections.abc import Callable
from dataclasses import dataclass


@dataclass
class MTRuntime:
    """Runtime context for Meaning Typed Programming."""

    caller: Callable[..., object]
    args: dict[int | str, object]
    call_params: dict[str, object]

    @staticmethod
    def factory(
        caller: Callable[..., object],
        args: dict[int | str, object],
        call_params: dict[str, object],
    ) -> "MTRuntime":
        """Create a new MTRuntime instance."""
        return MTRuntime(caller=caller, args=args, call_params=call_params)


@dataclass
class MTIR:
    """Intermediate Representation for Meaning Typed Programming."""

    caller: Callable[..., object]
    args: dict[int | str, object]
    call_params: dict[str, object]

    @property
    def runtime(self) -> MTRuntime:
        """Convert to runtime context."""
        return MTRuntime.factory(self.caller, self.args, self.call_params)



from typing import Any

change_table: Any

def modify_operation(dn, changes, auto_encode, schema=None, validator=None, check_names: bool = False): ...
def modify_request_to_dict(request): ...
def modify_response_to_dict(response): ...



from typing import Any

class VolumeApiMixin:
    def volumes(self, filters: dict[str, Any] | None = None) -> dict[str, Any]: ...
    def create_volume(
        self,
        name: str | None = None,
        driver: str | None = None,
        driver_opts: dict[str, Any] | None = None,
        labels: dict[str, Any] | None = None,
    ) -> dict[str, Any]: ...
    def inspect_volume(self, name: str) -> dict[str, Any]: ...
    def prune_volumes(self, filters: dict[str, Any] | None = None) -> dict[str, Any]: ...
    def remove_volume(self, name, force: bool = False) -> None: ...



from __future__ import annotations

import enum
import sys
from typing import Literal, Type
from typing_extensions import assert_type

A = enum.Enum("A", "spam eggs bacon")
B = enum.Enum("B", ["spam", "eggs", "bacon"])
C = enum.Enum("C", [("spam", 1), ("eggs", 2), ("bacon", 3)])
D = enum.Enum("D", {"spam": 1, "eggs": 2})

assert_type(A, Type[A])
assert_type(B, Type[B])
assert_type(C, Type[C])
assert_type(D, Type[D])


class EnumOfTuples(enum.Enum):
    X = 1, 2, 3
    Y = 4, 5, 6


assert_type(EnumOfTuples((1, 2, 3)), EnumOfTuples)

# TODO: ideally this test would pass:
#
# if sys.version_info >= (3, 12):
#     assert_type(EnumOfTuples(1, 2, 3), EnumOfTuples)


if sys.version_info >= (3, 11):

    class Foo(enum.StrEnum):
        X = enum.auto()

    assert_type(Foo.X, Literal[Foo.X])
    assert_type(Foo.X.value, str)



from _typeshed import Incomplete, Unused
from typing import ClassVar, Literal
from typing_extensions import Self

from openpyxl.chart.layout import Layout
from openpyxl.chart.shapes import GraphicalProperties
from openpyxl.chart.text import RichText
from openpyxl.descriptors.base import Alias, Typed, _ConvertibleToBool
from openpyxl.descriptors.excel import ExtensionList
from openpyxl.descriptors.nested import NestedBool
from openpyxl.descriptors.serialisable import Serialisable, _ChildSerialisableTreeElement
from openpyxl.xml.functions import Element

from ..xml._functions_overloads import _HasTagAndGet

class DataTable(Serialisable):
    tagname: ClassVar[str]
    showHorzBorder: NestedBool[Literal[True]]
    showVertBorder: NestedBool[Literal[True]]
    showOutline: NestedBool[Literal[True]]
    showKeys: NestedBool[Literal[True]]
    spPr: Typed[GraphicalProperties, Literal[True]]
    graphicalProperties: Alias
    txPr: Typed[RichText, Literal[True]]
    extLst: Typed[ExtensionList, Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        showHorzBorder: _HasTagAndGet[_ConvertibleToBool | None] | _ConvertibleToBool | None = None,
        showVertBorder: _HasTagAndGet[_ConvertibleToBool | None] | _ConvertibleToBool | None = None,
        showOutline: _HasTagAndGet[_ConvertibleToBool | None] | _ConvertibleToBool | None = None,
        showKeys: _HasTagAndGet[_ConvertibleToBool | None] | _ConvertibleToBool | None = None,
        spPr: GraphicalProperties | None = None,
        txPr: RichText | None = None,
        extLst: Unused = None,
    ) -> None: ...

class PlotArea(Serialisable):
    tagname: ClassVar[str]
    layout: Typed[Layout, Literal[True]]
    dTable: Typed[DataTable, Literal[True]]
    spPr: Typed[GraphicalProperties, Literal[True]]
    graphicalProperties: Alias
    extLst: Typed[ExtensionList, Literal[True]]
    areaChart: Incomplete
    area3DChart: Incomplete
    lineChart: Incomplete
    line3DChart: Incomplete
    stockChart: Incomplete
    radarChart: Incomplete
    scatterChart: Incomplete
    pieChart: Incomplete
    pie3DChart: Incomplete
    doughnutChart: Incomplete
    barChart: Incomplete
    bar3DChart: Incomplete
    ofPieChart: Incomplete
    surfaceChart: Incomplete
    surface3DChart: Incomplete
    bubbleChart: Incomplete
    valAx: Incomplete
    catAx: Incomplete
    dateAx: Incomplete
    serAx: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        layout: Layout | None = None,
        dTable: DataTable | None = None,
        spPr: GraphicalProperties | None = None,
        _charts=(),
        _axes=(),
        extLst: Unused = None,
    ) -> None: ...
    def to_tree(self, tagname: str | None = None, idx: Unused = None, namespace: Unused = None) -> Element: ...
    @classmethod
    def from_tree(cls, node: _ChildSerialisableTreeElement) -> Self: ...



from _typeshed import Incomplete

from antlr4.atn.ATNState import ATNState as ATNState
from antlr4.error.Errors import (
    FailedPredicateException as FailedPredicateException,
    InputMismatchException as InputMismatchException,
    NoViableAltException as NoViableAltException,
    ParseCancellationException as ParseCancellationException,
    RecognitionException as RecognitionException,
)
from antlr4.IntervalSet import IntervalSet as IntervalSet
from antlr4.Token import Token as Token

class ErrorStrategy:
    def reset(self, recognizer): ...
    def recoverInline(self, recognizer): ...
    def recover(self, recognizer, e: RecognitionException): ...
    def sync(self, recognizer): ...
    def inErrorRecoveryMode(self, recognizer): ...
    def reportError(self, recognizer, e: RecognitionException): ...

class DefaultErrorStrategy(ErrorStrategy):
    errorRecoveryMode: bool
    lastErrorIndex: int
    lastErrorStates: Incomplete
    nextTokensContext: Incomplete
    nextTokenState: int
    def __init__(self) -> None: ...
    def reset(self, recognizer): ...
    def beginErrorCondition(self, recognizer): ...
    def inErrorRecoveryMode(self, recognizer): ...
    def endErrorCondition(self, recognizer): ...
    def reportMatch(self, recognizer): ...
    def reportError(self, recognizer, e: RecognitionException): ...
    def recover(self, recognizer, e: RecognitionException): ...
    nextTokensState: Incomplete
    def sync(self, recognizer): ...
    def reportNoViableAlternative(self, recognizer, e: NoViableAltException): ...
    def reportInputMismatch(self, recognizer, e: InputMismatchException): ...
    def reportFailedPredicate(self, recognizer, e) -> None: ...
    def reportUnwantedToken(self, recognizer): ...
    def reportMissingToken(self, recognizer): ...
    def recoverInline(self, recognizer): ...
    def singleTokenInsertion(self, recognizer): ...
    def singleTokenDeletion(self, recognizer): ...
    def getMissingSymbol(self, recognizer): ...
    def getExpectedTokens(self, recognizer): ...
    def getTokenErrorDisplay(self, t: Token): ...
    def escapeWSAndQuote(self, s: str): ...
    def getErrorRecoverySet(self, recognizer): ...
    def consumeUntil(self, recognizer, set_: set[int]): ...

class BailErrorStrategy(DefaultErrorStrategy):
    def recover(self, recognizer, e: RecognitionException): ...
    def recoverInline(self, recognizer): ...
    def sync(self, recognizer): ...



from gevent._types import _Loop
from gevent.hub import Hub as _Hub

__all__ = ["get_hub", "get_hub_noargs", "get_hub_if_exists"]

Hub: type[_Hub] | None

def get_hub_class() -> type[_Hub] | None: ...
def set_default_hub_class(hubtype: type[_Hub]) -> None: ...
def get_hub() -> _Hub: ...
def get_hub_noargs() -> _Hub: ...
def get_hub_if_exists() -> _Hub | None: ...
def set_hub(hub: _Hub) -> None: ...
def get_loop() -> _Loop: ...
def set_loop(loop: _Loop) -> None: ...



from antlr4.Token import Token as Token

class IntervalSet:
    __slots__ = ("intervals", "readonly")
    intervals: list[range] | None
    readonly: bool
    def __init__(self) -> None: ...
    def __iter__(self): ...
    def __getitem__(self, item): ...
    def addOne(self, v: int): ...
    def addRange(self, v: range): ...
    def addSet(self, other: IntervalSet): ...
    def reduce(self, k: int): ...
    def complement(self, start: int, stop: int): ...
    def __contains__(self, item) -> bool: ...
    def __len__(self) -> int: ...
    def removeRange(self, v) -> None: ...
    def removeOne(self, v) -> None: ...
    def toString(self, literalNames: list[str], symbolicNames: list[str]): ...
    def elementName(self, literalNames: list[str], symbolicNames: list[str], a: int): ...



import datetime
from _typeshed import ConvertibleToInt
from typing import Final, SupportsIndex, overload

__version__: Final[str]
__all__ = ["LunarDate"]

class LunarDate:
    year: int
    month: int
    day: int
    isLeapMonth: bool
    def __init__(self, year: int, month: int, day: int, isLeapMonth: bool | None = False) -> None: ...
    @staticmethod
    def leapMonthForYear(year: int) -> int | None: ...
    @staticmethod
    def fromSolarDate(year: SupportsIndex, month: SupportsIndex, day: SupportsIndex) -> LunarDate: ...
    def toSolarDate(self) -> datetime.date: ...
    @overload
    def __sub__(self, other: LunarDate | datetime.date) -> datetime.timedelta: ...
    @overload
    def __sub__(self, other: datetime.timedelta) -> LunarDate: ...
    def __rsub__(self, other: datetime.date) -> datetime.timedelta: ...
    def __add__(self, other: datetime.timedelta) -> LunarDate: ...
    def __radd__(self, other: datetime.timedelta) -> LunarDate: ...
    def __eq__(self, other: object) -> bool: ...
    def __lt__(self, other: LunarDate | datetime.date) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __ge__(self, other: LunarDate | datetime.date) -> bool: ...
    @classmethod
    def today(cls) -> LunarDate: ...

yearInfos: Final[list[int]]

def yearInfo2yearDay(yearInfo: ConvertibleToInt) -> int: ...

yearDays: Final[list[int]]

def day2LunarDate(offset: ConvertibleToInt) -> None: ...



from _typeshed import Incomplete

from antlr4.atn.ATN import ATN as ATN
from antlr4.atn.ATNConfig import ATNConfig as ATNConfig
from antlr4.atn.SemanticContext import SemanticContext as SemanticContext
from antlr4.error.Errors import (
    IllegalStateException as IllegalStateException,
    UnsupportedOperationException as UnsupportedOperationException,
)
from antlr4.PredictionContext import merge as merge
from antlr4.Utils import str_list as str_list

ATNSimulator: Incomplete

class ATNConfigSet:
    __slots__ = (
        "configLookup",
        "fullCtx",
        "readonly",
        "configs",
        "uniqueAlt",
        "conflictingAlts",
        "hasSemanticContext",
        "dipsIntoOuterContext",
        "cachedHashCode",
    )
    configLookup: Incomplete
    fullCtx: Incomplete
    readonly: bool
    configs: Incomplete
    uniqueAlt: int
    conflictingAlts: Incomplete
    hasSemanticContext: bool
    dipsIntoOuterContext: bool
    cachedHashCode: int
    def __init__(self, fullCtx: bool = True) -> None: ...
    def __iter__(self): ...
    def add(self, config: ATNConfig, mergeCache=None): ...
    def getOrAdd(self, config: ATNConfig): ...
    def getStates(self): ...
    def getPredicates(self): ...
    def get(self, i: int): ...
    def optimizeConfigs(self, interpreter: ATNSimulator): ...
    def addAll(self, coll: list[Incomplete]): ...
    def __eq__(self, other): ...
    def __hash__(self): ...
    def hashConfigs(self): ...
    def __len__(self) -> int: ...
    def isEmpty(self): ...
    def __contains__(self, config) -> bool: ...
    def clear(self) -> None: ...
    def setReadonly(self, readonly: bool): ...

class OrderedATNConfigSet(ATNConfigSet):
    def __init__(self) -> None: ...



import abc
from typing import Any

from .common import RequestHandler, Response

class WebSocketResponse(Response):
    # Both raise NotImplementedError.
    def send(self, message: bytes | str) -> Any: ...
    def recv(self) -> Any: ...

class WebSocketRequestHandler(RequestHandler, abc.ABC, metaclass=abc.ABCMeta): ...



from collections.abc import Sequence

from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatchable
from numpy.random import RandomState

__all__ = ["is_threshold_graph", "find_threshold_graph"]

@_dispatchable
def is_threshold_graph(G: Graph[_Node]) -> bool: ...
def is_threshold_sequence(degree_sequence: Sequence[list[int]]) -> bool: ...
def creation_sequence(degree_sequence, with_labels=False, compact=False): ...
def make_compact(creation_sequence): ...
def uncompact(creation_sequence): ...
def creation_sequence_to_weights(creation_sequence): ...
def weights_to_creation_sequence(weights, threshold=1, with_labels=False, compact=False): ...
@_dispatchable
def threshold_graph(creation_sequence, create_using=None): ...
@_dispatchable
def find_alternating_4_cycle(G: Graph[_Node]): ...
@_dispatchable
def find_threshold_graph(G: Graph[_Node], create_using: Graph[_Node] | None = None): ...
@_dispatchable
def find_creation_sequence(G: Graph[_Node]): ...
def triangles(creation_sequence): ...
def triangle_sequence(creation_sequence): ...
def cluster_sequence(creation_sequence): ...
def degree_sequence(creation_sequence): ...
def density(creation_sequence): ...
def degree_correlation(creation_sequence): ...
def shortest_path(creation_sequence, u, v): ...
def shortest_path_length(creation_sequence, i): ...
def betweenness_sequence(creation_sequence, normalized=True): ...
def eigenvectors(creation_sequence): ...
def spectral_projection(u, eigenpairs): ...
def eigenvalues(creation_sequence): ...
def random_threshold_sequence(n, p, seed: int | RandomState | None = None): ...
def right_d_threshold_sequence(n: int, m: int) -> list[str]: ...
def left_d_threshold_sequence(n: int, m: int) -> list[str]: ...
def swap_d(cs, p_split=1.0, p_combine=1.0, seed: int | RandomState | None = None): ...



from collections.abc import Callable

from oauthlib.common import Request
from oauthlib.oauth2.rfc6749.tokens import TokenBase as TokenBase

from .request_validator import RequestValidator

class JWTToken(TokenBase):
    __slots__ = ("request_validator", "token_generator", "refresh_token_generator", "expires_in")
    request_validator: RequestValidator
    token_generator: Callable[[Request], str] | Callable[[Request, bool], str]
    refresh_token_generator: Callable[[Request], str] | Callable[[Request, bool], str]
    expires_in: int | Callable[[Request], int]
    def __init__(
        self,
        request_validator: RequestValidator | None = None,
        token_generator: Callable[[Request], str] | None = None,
        expires_in: int | Callable[[Request], int] | None = None,
        refresh_token_generator: Callable[[Request], str] | None = None,
    ) -> None: ...
    def create_token(self, request: Request, refresh_token: bool = False): ...
    def validate_request(self, request: Request): ...
    def estimate_type(self, request: Request): ...



from _typeshed import Incomplete

from authlib.jose.rfc7516 import JWEEncAlgorithm

class CBCHS2EncAlgorithm(JWEEncAlgorithm):
    IV_SIZE: int
    name: Incomplete
    description: Incomplete
    key_size: Incomplete
    key_len: Incomplete
    CEK_SIZE: Incomplete
    hash_alg: Incomplete
    def __init__(self, key_size, hash_type) -> None: ...
    def encrypt(self, msg, aad, iv, key): ...
    def decrypt(self, ciphertext, aad, iv, tag, key): ...

class GCMEncAlgorithm(JWEEncAlgorithm):
    IV_SIZE: int
    name: Incomplete
    description: Incomplete
    key_size: Incomplete
    CEK_SIZE: Incomplete
    def __init__(self, key_size) -> None: ...
    def encrypt(self, msg, aad, iv, key): ...
    def decrypt(self, ciphertext, aad, iv, tag, key): ...

JWE_ENC_ALGORITHMS: Incomplete



from typing import Any

from .resource import Collection, Model

class Volume(Model):
    id_attribute: str
    @property
    def name(self) -> str: ...
    def remove(self, force: bool = False) -> None: ...

class VolumeCollection(Collection[Volume]):
    model: type[Volume]
    def create(self, name: str | None = None, **kwargs) -> Volume: ...  # type:ignore[override]
    def get(self, volume_id: str) -> Volume: ...
    def list(self, **kwargs) -> list[Volume]: ...
    def prune(self, filters: dict[str, Any] | None = None) -> dict[str, Any]: ...



import ast
import sys
from _typeshed import StrOrLiteralStr, Unused
from collections.abc import Callable, Generator, Iterable, Iterator, Sequence
from contextlib import contextmanager
from re import Pattern
from typing import Any, ClassVar, Final, Literal, TypeVar, overload
from typing_extensions import Never, ParamSpec, TypeAlias

from pyflakes.messages import Message

_AnyFunction: TypeAlias = Callable[..., Any]
_F = TypeVar("_F", bound=_AnyFunction)
_P = ParamSpec("_P")

PYPY: Final[bool]
builtin_vars: Final[list[str]]

def parse_format_string(
    format_string: StrOrLiteralStr,
) -> Iterable[tuple[StrOrLiteralStr, StrOrLiteralStr | None, StrOrLiteralStr | None, StrOrLiteralStr | None]]: ...

if sys.version_info >= (3, 10):
    def getAlternatives(n: ast.If | ast.Try | ast.Match) -> list[ast.AST]: ...

else:
    def getAlternatives(n: ast.If | ast.Try) -> list[ast.AST]: ...

FOR_TYPES: Final[tuple[type[ast.For], type[ast.AsyncFor]]]
MAPPING_KEY_RE: Final[Pattern[str]]
CONVERSION_FLAG_RE: Final[Pattern[str]]
WIDTH_RE: Final[Pattern[str]]
PRECISION_RE: Final[Pattern[str]]
LENGTH_RE: Final[Pattern[str]]
VALID_CONVERSIONS: frozenset[str]

_FormatType: TypeAlias = tuple[str | None, str | None, str | None, str | None, str]
_PercentFormat: TypeAlias = tuple[str, _FormatType | None]

def parse_percent_format(s: str) -> tuple[_PercentFormat, ...]: ...

class _FieldsOrder(dict[type[ast.AST], tuple[str, ...]]):
    def __missing__(self, node_class: type[ast.AST]) -> tuple[str, ...]: ...

_OmitType: TypeAlias = str | tuple[str, ...] | None

def iter_child_nodes(node: ast.AST, omit: _OmitType = None, _fields_order: _FieldsOrder = ...) -> Iterator[ast.AST]: ...
@overload
def convert_to_value(item: ast.Constant) -> Any: ...  # type: ignore[overload-overlap]  # See ast.Constant.value for possible return types
@overload
def convert_to_value(item: ast.Tuple) -> tuple[Any, ...]: ...  # type: ignore[overload-overlap]  # Tuple items depend on their ast type
@overload
def convert_to_value(item: ast.Name) -> VariableKey: ...  # type: ignore[overload-overlap]
@overload
def convert_to_value(item: ast.AST) -> UnhandledKeyType: ...
def is_notimplemented_name_node(node: ast.AST) -> bool: ...

class Binding:
    name: str
    source: ast.AST | None
    used: Literal[False] | tuple[Scope, ast.AST]
    def __init__(self, name: str, source: ast.AST | None) -> None: ...
    def redefines(self, other: Binding) -> bool: ...

class Definition(Binding): ...

class Builtin(Definition):
    def __init__(self, name: str) -> None: ...

class UnhandledKeyType: ...

class VariableKey:
    name: str
    def __init__(self, item: ast.Name) -> None: ...
    def __eq__(self, compare: object) -> bool: ...
    def __hash__(self) -> int: ...

class Importation(Definition):
    fullName: str
    redefined: list[ast.AST]
    def __init__(self, name: str, source: ast.AST | None, full_name: str | None = None) -> None: ...
    @property
    def source_statement(self) -> str: ...

class SubmoduleImportation(Importation):
    def __init__(self, name: str, source: ast.Import | None) -> None: ...

class ImportationFrom(Importation):
    module: str
    real_name: str
    def __init__(self, name: str, source: ast.AST, module: str, real_name: str | None = None) -> None: ...

class StarImportation(Importation):
    def __init__(self, name: str, source: ast.AST) -> None: ...

class FutureImportation(ImportationFrom):
    used: tuple[Scope, ast.AST]
    def __init__(self, name: str, source: ast.AST, scope: Scope) -> None: ...

class Argument(Binding): ...
class Assignment(Binding): ...
class NamedExprAssignment(Assignment): ...

class Annotation(Binding):
    def redefines(self, other: Binding) -> Literal[False]: ...

class FunctionDefinition(Definition): ...
class ClassDefinition(Definition): ...

class ExportBinding(Binding):
    names: list[str]
    def __init__(self, name: str, source: ast.AST, scope: Scope) -> None: ...

class Scope(dict[str, Binding]):
    importStarred: bool

class ClassScope(Scope):
    def __init__(self) -> None: ...

class FunctionScope(Scope):
    usesLocals: bool
    alwaysUsed: ClassVar[set[str]]
    globals: set[str]
    returnValue: ast.expr | None
    isGenerator: bool
    def __init__(self) -> None: ...
    def unused_assignments(self) -> Iterator[tuple[str, Binding]]: ...
    def unused_annotations(self) -> Iterator[tuple[str, Annotation]]: ...

class TypeScope(Scope): ...
class GeneratorScope(Scope): ...
class ModuleScope(Scope): ...
class DoctestScope(ModuleScope): ...

class DetectClassScopedMagic:
    names: list[str]

def getNodeName(node: ast.AST) -> str: ...

TYPING_MODULES: frozenset[Literal["typing", "typing_extensions"]]

def is_typing_overload(value: Binding, scope_stack: Sequence[Scope]) -> bool: ...

class AnnotationState:
    NONE: ClassVar[Literal[0]]
    STRING: ClassVar[Literal[1]]
    BARE: ClassVar[Literal[2]]

def in_annotation(func: _F) -> _F: ...
def in_string_annotation(func: _F) -> _F: ...

if sys.version_info >= (3, 10):
    _Match: TypeAlias = ast.Match
    _MatchCase: TypeAlias = ast.match_case
    _MatchValue: TypeAlias = ast.MatchValue
    _MatchSingleton: TypeAlias = ast.MatchSingleton
    _MatchSequence: TypeAlias = ast.MatchSequence
    _MatchStar: TypeAlias = ast.MatchStar
    _MatchMapping: TypeAlias = ast.MatchMapping
    _MatchClass: TypeAlias = ast.MatchClass
    _MatchAs: TypeAlias = ast.MatchAs
    _MatchOr: TypeAlias = ast.MatchOr
else:
    # The methods using these should never be called on Python < 3.10.
    _Match: TypeAlias = Never
    _MatchCase: TypeAlias = Never
    _MatchValue: TypeAlias = Never
    _MatchSingleton: TypeAlias = Never
    _MatchSequence: TypeAlias = Never
    _MatchStar: TypeAlias = Never
    _MatchMapping: TypeAlias = Never
    _MatchClass: TypeAlias = Never
    _MatchAs: TypeAlias = Never
    _MatchOr: TypeAlias = Never

if sys.version_info >= (3, 12):
    _TypeVar: TypeAlias = ast.TypeVar
    _ParamSpec: TypeAlias = ast.ParamSpec
    _TypeVarTuple: TypeAlias = ast.TypeVarTuple
    _TypeAlias: TypeAlias = ast.TypeAlias
else:
    # The methods using these should never be called on Python < 3.12.
    _TypeVar: TypeAlias = Never
    _ParamSpec: TypeAlias = Never
    _TypeVarTuple: TypeAlias = Never
    _TypeAlias: TypeAlias = Never

if sys.version_info >= (3, 14):
    _NameConstant: TypeAlias = Never
    _TemplateStr: TypeAlias = ast.TemplateStr
    _Interpolation: TypeAlias = ast.Interpolation
else:
    _NameConstant: TypeAlias = ast.NameConstant
    # The methods using these should never be called on Python < 3.14.
    _TemplateStr: TypeAlias = Never
    _Interpolation: TypeAlias = Never

class Checker:
    nodeDepth: int
    offset: tuple[int, int] | None
    builtIns: set[str]
    deadScopes: list[Scope]
    messages: list[Message]
    filename: str
    withDoctest: bool
    scopeStack: list[Scope]
    exceptHandlers: list[tuple[()] | str]
    root: ast.AST
    def __init__(
        self,
        tree: ast.AST,
        filename: str = "(none)",
        builtins: Iterable[str] | None = None,
        withDoctest: bool = False,
        file_tokens: Unused = (),
    ) -> None: ...
    def deferFunction(self, callable: _AnyFunction) -> None: ...
    @property
    def futuresAllowed(self) -> bool: ...
    @futuresAllowed.setter
    def futuresAllowed(self, value: Literal[False]) -> None: ...
    @property
    def annotationsFutureEnabled(self) -> bool: ...
    @annotationsFutureEnabled.setter
    def annotationsFutureEnabled(self, value: Literal[True]) -> None: ...
    @property
    def scope(self) -> Scope: ...
    @contextmanager
    def in_scope(self, cls: Callable[[], Scope]) -> Generator[None]: ...
    def checkDeadScopes(self) -> None: ...
    def report(self, messageClass: Callable[_P, Message], *args: _P.args, **kwargs: _P.kwargs) -> None: ...
    def getParent(self, node: ast.AST) -> ast.AST: ...
    def getCommonAncestor(self, lnode: ast.AST, rnode: ast.AST, stop: ast.AST) -> ast.AST: ...
    def descendantOf(self, node: ast.AST, ancestors: ast.AST, stop: ast.AST) -> bool: ...
    def getScopeNode(self, node: ast.AST) -> ast.AST | None: ...
    def differentForks(self, lnode: ast.AST, rnode: ast.AST) -> bool: ...
    def addBinding(self, node: ast.AST, value: Binding) -> None: ...
    def getNodeHandler(self, node_class: type[ast.AST]) -> Callable[[ast.AST], None]: ...
    def handleNodeLoad(self, node: ast.AST, parent: ast.AST | None) -> None: ...
    def handleNodeStore(self, node: ast.AST) -> None: ...
    def handleNodeDelete(self, node: ast.AST) -> None: ...
    def handleChildren(self, tree: ast.AST, omit: _OmitType = None) -> None: ...
    def isLiteralTupleUnpacking(self, node: ast.AST) -> bool | None: ...
    def isDocstring(self, node: ast.AST) -> bool: ...
    def getDocstring(self, node: ast.AST) -> tuple[str, int] | tuple[None, None]: ...
    def handleNode(self, node: ast.AST | None, parent: ast.AST | None) -> None: ...
    def handleDoctests(self, node: ast.AST) -> None: ...
    def handleStringAnnotation(self, s: str, node: ast.AST, ref_lineno: int, ref_col_offset: int, err: type[Message]) -> None: ...
    def handle_annotation_always_deferred(self, annotation: ast.AST, parent: ast.AST) -> None: ...
    def handleAnnotation(self, annotation: ast.AST, node: ast.AST) -> None: ...
    def ignore(self, node: ast.AST) -> None: ...
    def DELETE(self, tree: ast.Delete, omit: _OmitType = None) -> None: ...
    def FOR(self, tree: ast.For, omit: _OmitType = None) -> None: ...
    def ASYNCFOR(self, tree: ast.AsyncFor, omit: _OmitType = None) -> None: ...
    def WHILE(self, tree: ast.While, omit: _OmitType = None) -> None: ...
    def WITH(self, tree: ast.With, omit: _OmitType = None) -> None: ...
    def WITHITEM(self, tree: ast.AST, omit: _OmitType = None) -> None: ...
    def ASYNCWITH(self, tree: ast.AsyncWith, omit: _OmitType = None) -> None: ...
    def EXPR(self, tree: ast.AST, omit: _OmitType = None) -> None: ...
    def ASSIGN(self, tree: ast.Assign, omit: _OmitType = None) -> None: ...
    def PASS(self, node: ast.AST) -> None: ...
    def BOOLOP(self, tree: ast.BoolOp, omit: _OmitType = None) -> None: ...
    def UNARYOP(self, tree: ast.UnaryOp, omit: _OmitType = None) -> None: ...
    def SET(self, tree: ast.Set, omit: _OmitType = None) -> None: ...
    def ATTRIBUTE(self, tree: ast.Attribute, omit: _OmitType = None) -> None: ...
    def STARRED(self, tree: ast.Starred, omit: _OmitType = None) -> None: ...
    def NAMECONSTANT(self, tree: _NameConstant, omit: _OmitType = None) -> None: ...
    def NAMEDEXPR(self, tree: ast.NamedExpr, omit: _OmitType = None) -> None: ...
    def SUBSCRIPT(self, node: ast.Subscript) -> None: ...
    def CALL(self, node: ast.Call) -> None: ...
    def BINOP(self, node: ast.BinOp) -> None: ...
    def CONSTANT(self, node: ast.Constant) -> None: ...
    def SLICE(self, tree: ast.Slice, omit: _OmitType = None) -> None: ...
    def EXTSLICE(self, tree: ast.ExtSlice, omit: _OmitType = None) -> None: ...
    def INDEX(self, tree: ast.Index, omit: _OmitType = None) -> None: ...
    def LOAD(self, node: ast.Load) -> None: ...
    def STORE(self, node: ast.Store) -> None: ...
    def DEL(self, node: ast.Del) -> None: ...
    def AUGLOAD(self, node: ast.AugLoad) -> None: ...
    def AUGSTORE(self, node: ast.AugStore) -> None: ...
    def PARAM(self, node: ast.Param) -> None: ...
    def AND(self, node: ast.And) -> None: ...
    def OR(self, node: ast.Or) -> None: ...
    def ADD(self, node: ast.Add) -> None: ...
    def SUB(self, node: ast.Sub) -> None: ...
    def MULT(self, node: ast.Mult) -> None: ...
    def DIV(self, node: ast.Div) -> None: ...
    def MOD(self, node: ast.Mod) -> None: ...
    def POW(self, node: ast.Pow) -> None: ...
    def LSHIFT(self, node: ast.LShift) -> None: ...
    def RSHIFT(self, node: ast.RShift) -> None: ...
    def BITOR(self, node: ast.BitOr) -> None: ...
    def BITXOR(self, node: ast.BitXor) -> None: ...
    def BITAND(self, node: ast.BitAnd) -> None: ...
    def FLOORDIV(self, node: ast.FloorDiv) -> None: ...
    def INVERT(self, node: ast.Invert) -> None: ...
    def NOT(self, node: ast.Not) -> None: ...
    def UADD(self, node: ast.UAdd) -> None: ...
    def USUB(self, node: ast.USub) -> None: ...
    def EQ(self, node: ast.Eq) -> None: ...
    def NOTEQ(self, node: ast.NotEq) -> None: ...
    def LT(self, node: ast.Lt) -> None: ...
    def LTE(self, node: ast.LtE) -> None: ...
    def GT(self, node: ast.Gt) -> None: ...
    def GTE(self, node: ast.GtE) -> None: ...
    def IS(self, node: ast.Is) -> None: ...
    def ISNOT(self, node: ast.IsNot) -> None: ...
    def IN(self, node: ast.In) -> None: ...
    def NOTIN(self, node: ast.NotIn) -> None: ...
    def MATMULT(self, node: ast.MatMult) -> None: ...
    def RAISE(self, node: ast.Raise) -> None: ...
    def COMPREHENSION(self, tree: ast.comprehension, omit: _OmitType = None) -> None: ...
    def KEYWORD(self, tree: ast.keyword, omit: _OmitType = None) -> None: ...
    def FORMATTEDVALUE(self, tree: ast.FormattedValue, omit: _OmitType = None) -> None: ...
    def JOINEDSTR(self, node: ast.AST) -> None: ...
    def TEMPLATESTR(self, node: _TemplateStr) -> None: ...
    def INTERPOLATION(self, tree: _Interpolation, omit: _OmitType = None) -> None: ...
    def DICT(self, node: ast.Dict) -> None: ...
    def IF(self, node: ast.If) -> None: ...
    def IFEXP(self, node: ast.If) -> None: ...
    def ASSERT(self, node: ast.Assert) -> None: ...
    def GLOBAL(self, node: ast.Global) -> None: ...
    def NONLOCAL(self, node: ast.Nonlocal) -> None: ...
    def GENERATOREXP(self, node: ast.GeneratorExp) -> None: ...
    def LISTCOMP(self, node: ast.ListComp) -> None: ...
    def DICTCOMP(self, node: ast.DictComp) -> None: ...
    def SETCOMP(self, node: ast.SetComp) -> None: ...
    def NAME(self, node: ast.Name) -> None: ...
    def CONTINUE(self, node: ast.Continue) -> None: ...
    def BREAK(self, node: ast.Break) -> None: ...
    def RETURN(self, node: ast.Return) -> None: ...
    def YIELD(self, node: ast.Yield) -> None: ...
    def AWAIT(self, node: ast.Await) -> None: ...
    def YIELDFROM(self, node: ast.YieldFrom) -> None: ...
    def FUNCTIONDEF(self, node: ast.FunctionDef) -> None: ...
    def ASYNCFUNCTIONDEF(self, node: ast.AsyncFunctionDef) -> None: ...
    def LAMBDA(self, node: ast.Lambda) -> None: ...
    def ARGUMENTS(self, node: ast.arguments) -> None: ...
    def ARG(self, node: ast.arg) -> None: ...
    def CLASSDEF(self, node: ast.ClassDef) -> None: ...
    def AUGASSIGN(self, node: ast.AugAssign) -> None: ...
    def TUPLE(self, node: ast.Tuple) -> None: ...
    def LIST(self, node: ast.List) -> None: ...
    def IMPORT(self, node: ast.Import) -> None: ...
    def IMPORTFROM(self, node: ast.ImportFrom) -> None: ...
    def TRY(self, node: ast.Try) -> None: ...
    if sys.version_info >= (3, 11):
        def TRYSTAR(self, node: ast.TryStar) -> None: ...
    else:
        def TRYSTAR(self, node: ast.Try) -> None: ...

    def EXCEPTHANDLER(self, node: ast.ExceptHandler) -> None: ...
    def ANNASSIGN(self, node: ast.AnnAssign) -> None: ...
    def COMPARE(self, node: ast.Compare) -> None: ...
    def MATCH(self, tree: _Match, omit: _OmitType = None) -> None: ...
    def MATCH_CASE(self, tree: _MatchCase, omit: _OmitType = None) -> None: ...
    def MATCHCLASS(self, tree: _MatchClass, omit: _OmitType = None) -> None: ...
    def MATCHOR(self, tree: _MatchOr, omit: _OmitType = None) -> None: ...
    def MATCHSEQUENCE(self, tree: _MatchSequence, omit: _OmitType = None) -> None: ...
    def MATCHSINGLETON(self, tree: _MatchSingleton, omit: _OmitType = None) -> None: ...
    def MATCHVALUE(self, tree: _MatchValue, omit: _OmitType = None) -> None: ...
    def MATCHAS(self, node: _MatchAs) -> None: ...
    def MATCHMAPPING(self, node: _MatchMapping) -> None: ...
    def MATCHSTAR(self, node: _MatchStar) -> None: ...
    def TYPEVAR(self, node: _TypeVar) -> None: ...
    def PARAMSPEC(self, node: _ParamSpec) -> None: ...
    def TYPEVARTUPLE(self, node: _TypeVarTuple) -> None: ...
    def TYPEALIAS(self, node: _TypeAlias) -> None: ...



from _typeshed import Incomplete, SupportsGetItem

from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatchable

__all__ = ["katz_centrality", "katz_centrality_numpy"]

@_dispatchable
def katz_centrality(
    G: Graph[_Node],
    alpha: float | None = 0.1,
    beta: float | SupportsGetItem[Incomplete, Incomplete] | None = 1.0,
    max_iter: int | None = 1000,
    tol: float | None = 1e-06,
    nstart: SupportsGetItem[Incomplete, Incomplete] | None = None,
    normalized: bool | None = True,
    weight: str | None = None,
) -> dict[Incomplete, Incomplete]: ...
@_dispatchable
def katz_centrality_numpy(
    G: Graph[_Node],
    alpha: float = 0.1,
    beta: float | SupportsGetItem[Incomplete, Incomplete] | None = 1.0,
    normalized: bool = True,
    weight: str | None = None,
) -> dict[Incomplete, Incomplete]: ...
